OC.L10N.register(
    "spreed",
    {
    "a conversation" : "μια συνομιλία",
    "(Duration %s)" : "(Διάρκεια %s)",
    "You attended a call with {user1}" : "Παρακολουθήσατε μια κλήση με {user1}",
    "_%n guest_::_%n guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    "You attended a call with {user1} and {user2}" : "Παρακολουθήσατε μια κλήση με {user1} και {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2} και {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2}, {user3} και {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2}, {user3}, {user4} και {user5}",
    "_%n other_::_%n others_" : ["%n άλλος","%n άλλοι"],
    "{actor} invited you to {call}" : "Ο {actor} σας προσκάλεσε σε {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Σας προσκάλεσαν για <strong>συζήτηση</strong> ή είχατε μια <strong>κλήση</strong>",
    "Other activities" : "Άλλες δραστηριότητες",
    "Talk" : "Talk",
    "Guest" : "Επισκέπτης",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Καλώς ήρθατε στο Nextcloud Talk!\nΣε αυτή τη συνομιλία θα ενημερώνεστε για νέες λειτουργίες που είναι διαθέσιμες στο Nextcloud Talk.",
    "## New in Talk %s" : "## Νέα στο Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Το Microsoft Edge και Safari μπορούν να χρησιμοποιηθούν για κλήσεις βίντεο και ήχου",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Οι συνομιλίες ένας προς ένα είναι σταθερές και δεν μπορούν πλέον να μετατραπούν σε ομαδικές συνομιλίες τυχαία. Επίσης, όταν ένας από τους συμμετέχοντες αποχωρήσει από τη συζήτηση, αυτή δε διαγράφεται αυτόματα πλέον. Μόνο εάν και οι δύο συμμετέχοντες αποχωρήσουν, διαγράφεται από το διακομιστή",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Μπορείτε να ενημερώσετε όλους τους συμμετέχοντες γράφοντας \"@all\" στο chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Με το \"βελάκι-πάνω\" ξανά γράφεται το τελευταίο μήνυμα",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Το Talk έχει πλέον εντολές, στείλτε \"/help\" σαν μήνυμα στο chat για να δείτε εάν ο διαχειριστής ρύθμισε κάποιες",
    "- With projects you can create quick links between conversations, files and other items" : "- Με τα έργα μπορείτε να δημιουργήσετε γρήγορους συνδέσμους μεταξύ συνομιλιών, αρχείων και άλλων αντικειμένων",
    "- You can now mention guests in the chat" : "Μππορείτε πλέον να αναφερθείτε σε επισκέπτες στο chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Οι συνομιλίες έχουν πλέον αίθουσα αναμονής. Αυτό επιτρέπει στους συντονιστές να προετοιμαστούν για την συνάντηση, ενώ οι χρήστες και οι επισκέπτες πρέπει να περιμένουν",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "Μπορείτε πλέον να απαντήσετε απευθείας στα μηνύματα άλλων χρηστών δίνοντας άλλο ύφος στον ορισμό των μηνυμάτων",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Η αναζήτηση συζητήσεων και συμμετεχόντων φιλτράρει τις υπάρχουσες συνομιλίες σας, διευκολύνοντας την εύρεση προηγούμενων συνομιλιών",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Τώρα μπορείτε να προσθέσετε προσαρμοσμένες ομάδες χρηστών σε συνομιλίες όταν είναι εγκατεστημένη η εφαρμογή κύκλων",
    "- Check out the new grid and call view" : "- Ελέγξτε τη νέα προβολή πλέγματος και κλήσεων",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Τώρα μπορείτε να ανεβάσετε και να σύρετε αρχεία απευθείας από τη συσκευή σας στη συνομιλία γραπτών μηνυμάτων",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Τα κοινόχρηστα αρχεία ανοίγουν τώρα απευθείας μέσα στον χώρο συνομιλίας με τις εφαρμογές προβολής",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Τώρα μπορείτε να αναζητήσετε συνομιλίες και μηνύματα στην ενοποιημένη αναζήτηση στην επάνω γραμμή.",
    "- Spice up your messages with emojis from the emoji picker" : "- Εμπλουτίστε τα μηνύματά σας με emojis από την επιλογή emoji.",
    "- You can now change your camera and microphone while being in a call" : "- Τώρα μπορείτε να αλλάξετε την κάμερα και το μικρόφωνό σας ενώ βρίσκεστε σε κλήση.",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Δώστε πλαίσιο στις συνομιλίες σας με μια περιγραφή και ανοίξτε τις ώστε οι συνδεδεμένοι χρήστες να μπορούν να τις βρουν και να συμμετάσχουν μόνοι τους",
    "- See a read status and send failed messages again" : "- Δείτε την κατάσταση ανάγνωσης και στείλτε ξανά μηνύματα που απέτυχαν",
    "- Raise your hand in a call with the R key" : "Σηκώστε το χέρι σας σε μια κλήση με το πλήκτρο R",
    "- Join the same conversation and call from multiple devices" : "- Συμμετέχετε στην ίδια συνομιλία και κλήση από πολλαπλές συσκευές",
    "- Send voice messages, share your location or contact details" : "- Στείλτε φωνητικά μηνύματα, μοιραστείτε την τοποθεσία σας ή τα στοιχεία επικοινωνίας",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Προσθέστε ομάδες σε μια συνομιλία και τα νέα μέλη ομάδας θα προστεθούν αυτόματα ως συμμετέχοντες",
    "- A preview of your audio and video is shown before joining a call" : "- Μια προεπισκόπηση του ήχου και βίντεό σας εμφανίζεται πριν από τη συμμετοχή σε κλήση",
    "- You can now blur your background in the newly designed call view" : "- Μπορείτε τώρα να θολώσετε το φόντο σας στη νέα σχεδιασμένη προβολή κλήσης",
    "- Moderators can now assign general and individual permissions to participants" : "- Οι συντονιστές μπορούν τώρα να αναθέτουν γενικά και ατομικά δικαιώματα σε συμμετέχοντες",
    "- You can now react to chat messages" : "- Μπορείτε τώρα να αντιδράτε σε μηνύματα συνομιλίας",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Στην πλαϊνή γραμμή μπορείτε τώρα να βρείτε μια επισκόπηση των τελευταίων κοινόχρηστων στοιχείων",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Χρησιμοποιήστε μια δημοσκόπηση για να συλλέξετε τις απόψεις άλλων ή να κανονίσετε μια ημερομηνία",
    "- Configure an expiration time for chat messages" : "- Ρυθμίστε ένα χρόνο λήξης για τα μηνύματα συνομιλίας",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Ξεκινήστε κλήσεις χωρίς ειδοποίηση άλλων σε μεγάλες συνομιλίες. Μπορείτε να στείλετε ατομικές ειδοποιήσεις κλήσης μόλις ξεκινήσει η κλήση.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Στείλτε μηνύματα συνομιλίας χωρίς ειδοποίηση των παραληπτών σε περίπτωση που δεν είναι επείγον",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Τα emojis μπορούν τώρα να συμπληρωθούν αυτόματα πληκτρολογώντας \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Συνδέστε διάφορα στοιχεία χρησιμοποιώντας τον νέο έξυπνο επιλογέα πληκτρολογώντας \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Οι συντονιστές μπορούν τώρα να δημιουργούν δωμάτια ομάδων (απαιτείται το High-performance backend)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Οι κλήσεις μπορούν τώρα να εγγράφονται (απαιτείται το High-performance backend)",
    "- Conversations can now have an avatar or emoji as icon" : "- Οι συνομιλίες μπορούν τώρα να έχουν avatar ή emoji ως εικονίδιο",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Τα εικονικά φόντα είναι τώρα διαθέσιμα εκτός από το θολωμένο φόντο σε κλήσεις βίντεο",
    "- Reactions are now available during calls" : "- Οι αντιδράσεις είναι τώρα διαθέσιμες κατά τη διάρκεια κλήσεων",
    "- Typing indicators show which users are currently typing a message" : "- Οι δείκτες πληκτρολόγησης δείχνουν ποιοι χρήστες πληκτρολογούν τρέχοντα μήνυμα",
    "- Groups can now be mentioned in chats" : "- Οι ομάδες μπορούν τώρα να αναφέρονται σε συνομιλίες",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Οι εγγραφές κλήσεων μεταγράφονται αυτόματα εάν έχει εγγραφεί εφαρμογή πάροχου μεταγραφής",
    "- Chat messages can be translated if a translation provider app is registered" : "- Τα μηνύματα συνομιλίας μπορούν να μεταφραστούν εάν έχει εγγραφεί εφαρμογή πάροχου μετάφρασης",
    "- **Markdown** can now be used in _chat_ messages" : "- Το **Markdown** μπορεί τώρα να χρησιμοποιηθεί σε μηνύματα _συνομιλίας_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Τα Webhooks είναι τώρα διαθέσιμα για την υλοποίηση bots. Δείτε την τεκμηρίωση για περισσότερες πληροφορίες https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Ορίστε υπενθύμιση σε μήνυμα συνομιλίας για να ειδοποιηθείτε ξανά αργότερα",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Χρησιμοποιήστε τη συνομιλία **Σημείωση προς εμένα** για να κρατάτε σημειώσεις και να μοιράζεστε πληροφορίες ανάμεσα στις συσκευές σας",
    "- Captions allow to send a message with a file at the same time" : "- Οι λεζάντες επιτρέπουν την αποστολή μηνύματος με αρχείο ταυτόχρονα",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Το βίντεο του ομιλητή είναι τώρα ορατό κατά τη διάρκεια κοινής χρήσης οθόνης και οι αντιδράσεις κλήσης είναι κινούμενες",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Τα μηνύματα μπορούν τώρα να επεξεργαστούν από συνδεδεμένους συγγραφείς και συντονιστές για 6 ώρες",
    "- Unsent message drafts are now saved in your browser" : "- Τα μη αποσταλμένα προσχέδια μηνυμάτων αποθηκεύονται τώρα στο πρόγραμμα περιήγησής σας",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Η συνομιλία κειμένου μπορεί τώρα να γίνει με federated τρόπο με άλλους διακομιστές Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Οι συντονιστές μπορούν τώρα να αποκλείσουν λογαριασμούς και επισκέπτες για να τους εμποδίσουν από το να επανέλθουν σε συνομιλία",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Οι επερχόμενες κλήσεις από συνδεδεμένα γεγονότα ημερολογίου και αντικαταστάτες εκτός γραφείου εμφανίζονται τώρα σε συνομιλίες",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Οι κλήσεις μπορούν τώρα να γίνουν με federated τρόπο με άλλους διακομιστές Talk (απαιτείται το High-performance backend)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Παρουσίαση του πελάτη επιφάνειας εργασίας Nextcloud Talk για Windows, macOS και Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Σύνοψη εγγραφών κλήσεων και μη αναγνωσμένων μηνυμάτων σε συνομιλίες με τον Βοηθό Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Βελτιωμένες συναντήσεις με αναγνώριση επισκεπτών που προσκλήθηκαν μέσω διεύθυνσης email, εισαγωγή λιστών συμμετεχόντων, προσχέδια για δημοσκοπήσεις και λήψη λιστών συμμετεχόντων κλήσης",
    "- Archive conversations to stay focused" : "- Αρχειοθέτηση συνομιλιών για να παραμείνετε συγκεντρωμένοι",
    "- Schedule a meeting into your calendar from within a conversation" : "- Προγραμματίστε μια συνάντηση στο ημερολόγιό σας από μέσα σε μια συνομιλία",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Αναζήτηση μηνυμάτων της τρέχουσας συνομιλίας απευθείας στην δεξιά πλαϊνή γραμμή",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Δείτε περισσότερες συνομιλίες με μια πρώτη ματιά με τη νέα συμπαγή λίστα (ενεργοποιήστε στις ρυθμίσεις Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Οι συνομιλίες συναντήσεων συγχρονίζουν τώρα τον τίτλο και την περιγραφή από το ημερολόγιο και είναι κρυφές με ένα φίλτρο αναζήτησης μέχρι να πλησιάσει η ώρα έναρξης",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Σημειώστε συνομιλίες ως ευαίσθητες στις ρυθμίσεις ειδοποιήσεων, για απόκρυψη του περιεχομένου μηνύματος από τη λίστα συνομιλιών και τις ειδοποιήσεις",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Για λήψη push ειδοποιήσεων κατά τη διάρκεια \"Μην ενοχλείτε\", σημειώστε συνομιλίες ως σημαντικές",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Προσθέστε άλλους συμμετέχοντες σε κλήση ένα προς ένα για δημιουργία νέας ομαδικής κλήσης αυτόματα",
    "- Use threads to keep your chat and discussions organized" : "- Χρησιμοποιήστε νήματα για να διατηρήσετε τις συνομιλίες και συζητήσεις σας οργανωμένες",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Ζωντανές μεταγραφές τώρα διαθέσιμες κατά τη διάρκεια κλήσης (απαιτείται η εφαρμογή live-transcription ExApp και το High-performance backend)",
    "_All %n participant_::_All %n participants_" : ["Όλοι οι %n συμμετέχοντες","Όλοι οι %n συμμετέχοντες"],
    "Talk updates ✅" : "Ενημερώσεις Talk ✅",
    "Reaction deleted by author" : "Αντίδραση διαγραμμένη από τον συγγραφέα",
    "{actor} created the conversation" : "Ο/Η {actor} δημιούργησε την συζήτηση",
    "You created the conversation" : "Δημιουργήσατε μια συζήτηση",
    "System created the conversation" : "Το σύστημα δημιούργησε τη συνομιλία",
    "An administrator created the conversation" : "Ένας διαχειριστής δημιούργησε την συζήτηση",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ο/Η {actor} μετονόμασε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Μετονομάσατε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ένας διαχειριστής μετονόμασε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "{actor} set the description" : "Ο/Η {actor} όρισε την περιγραφή",
    "You set the description" : "Ορίσατε την περιγραφή",
    "An administrator set the description" : "Ένας διαχειριστής όρισε την περιγραφή",
    "{actor} removed the description" : "Ο/Η {actor} κατάργησε την περιγραφή",
    "You removed the description" : "Καταργήσατε την περιγραφή",
    "An administrator removed the description" : "Ένας διαχειριστής κατάργησε την περιγραφή",
    "You started a silent call" : "Ξεκινήσατε μια σιωπηλή κλήση",
    "Outgoing silent call" : "Εξερχόμενη σιωπηλή κλήση",
    "{actor} started a silent call" : "Ο/Η {actor} ξεκίνησε μια σιωπηλή κλήση",
    "Incoming silent call" : "Εισερχόμενη σιωπηλή κλήση",
    "You started a call" : "Ξεκινήσατε μια κλήση",
    "Outgoing call" : "Εξερχόμενη κλήση",
    "{actor} started a call" : "Ο/Η {actor} ξεκίνησε μια κλήση",
    "Incoming call" : "Εισερχόμενη κλήση",
    "{actor} joined the call" : "Ο/Η {actor} συμμετέχει στην κλήση",
    "You joined the call" : "Συμμετείχατε στην κλήση",
    "{actor} left the call" : "Ο/Η {actor} αποχώρησε από την κλήση",
    "You left the call" : "Αποχωρήσατε από την κλήση",
    "{actor} unlocked the conversation" : "Ο/Η {actor} ξεκλείδωσε την συζήτηση",
    "You unlocked the conversation" : "Ξεκλειδώσατε την συζήτηση",
    "An administrator unlocked the conversation" : "Ένας διαχειριστής ξεκλείδωσε την συζήτηση",
    "{actor} locked the conversation" : "Ο/Η {actor} κλείδωσε την συζήτηση",
    "You locked the conversation" : "Κλειδώσατε την συζήτηση",
    "An administrator locked the conversation" : "Ένας διαχειριστής κλείδωσε την συζήτηση",
    "{actor} limited the conversation to the current participants" : "Ο/Η {actor} περιόρισε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "You limited the conversation to the current participants" : "Περιορίσατε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "An administrator limited the conversation to the current participants" : "Ένας διαχειριστής περιόρισε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "{actor} opened the conversation to registered users" : "Ο/Η {actor} άνοιξε την συνομιλία σε εγγεγραμμένους χρήστες",
    "You opened the conversation to registered users" : "Ανοίξατε την συνομιλία σε εγγεγραμμένους χρήστες",
    "An administrator opened the conversation to registered users" : "Ένας διαχειριστής άνοιξε την συνομιλία για εγγεγραμμένους χρήστες",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "Ο {actor} άνοιξε τη συνομιλία σε εγγεγραμμένους χρήστες και χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "You opened the conversation to registered users and users created with the Guests app" : "Ανοίξατε τη συνομιλία σε εγγεγραμμένους χρήστες και χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Ένας διαχειριστής άνοιξε τη συνομιλία σε εγγεγραμμένους χρήστες και χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "The conversation is now open to everyone" : "Η συζήτηση είναι πλέον ανοιχτή για όλους",
    "{actor} opened the conversation to everyone" : "Ο/Η {actor} άνοιξε την συζήτηση για όλους",
    "You opened the conversation to everyone" : "Ανοίξατε την συζήτηση για όλους",
    "{actor} restricted the conversation to moderators" : "Ο/Η {actor} περιόρισε την συζήτηση για συντονιστές",
    "You restricted the conversation to moderators" : "Περιορίσατε την συζήτηση για συντονιστές",
    "{actor} started breakout rooms" : "Ο/Η {actor} ξεκίνησε τα δωμάτια ομάδων",
    "You started breakout rooms" : "Ξεκινήσατε τα δωμάτια ομάδων",
    "{actor} stopped breakout rooms" : "Ο/Η {actor} σταμάτησε τα δωμάτια ομάδων",
    "You stopped breakout rooms" : "Σταματήσατε τα δωμάτια ομάδων",
    "{actor} allowed guests" : "Ο/Η {actor} επέτρεψε τους επισκέπτες",
    "You allowed guests" : "Επιτρέψατε τους επισκέπτες",
    "An administrator allowed guests" : "Ένας διαχειριστής επέτρεψε τους επισκέπτες",
    "{actor} disallowed guests" : "Ο/Η {actor} απαγόρευσε τους επισκέπτες",
    "You disallowed guests" : "Απαγορέψατε τους επισκέπτες",
    "An administrator disallowed guests" : "Ένας διαχειριστής απαγόρευσε τους επισκέπτες",
    "{actor} set a password" : "Ο/Η {actor} όρισε κωδικό",
    "You set a password" : "Ορίσατε κωδικό",
    "An administrator set a password" : "Ένας διαχειριστής όρισε κωδικό",
    "{actor} removed the password" : "Ο/Η {actor} αφαίρεσε τον κωδικό",
    "You removed the password" : "Αφαιρέσατε το συνθηματικό",
    "An administrator removed the password" : "Ένας διαχειριστής αφαίρεσε το συνθηματικό",
    "{actor} added {user}" : "Ο/Η {actor} πρόσθεσε τον/την {user}",
    "You joined the conversation" : "Συνδεθήκατε στην συζήτηση",
    "{actor} joined the conversation" : "Ο/Η {actor} συνδέθηκε στην συζήτηση",
    "You added {user}" : "Προσθέσατε τον/την {user}",
    "{actor} added you" : "Ο/Η {actor} σας πρόσθεσε",
    "An administrator added you" : "Ένας διαχειριστής σάς πρόσθεσε",
    "An administrator added {user}" : "Ένας διαχειριστής πρόσθεσε τον/την χρήστη {user}",
    "You left the conversation" : "Αποχωρήσατε από την συζήτηση",
    "{actor} left the conversation" : "Ο/Η {actor} αποχώρησε από την συζήτηση",
    "{actor} removed {user}" : "Ο/Η {actor} αφαίρεσε τον/την {user}",
    "You removed {user}" : "Αφαιρέσατε τον/την {user}",
    "{actor} removed you" : "Ο/Η {actor} σας αφαίρεσε",
    "An administrator removed you" : "Ένας διαχειριστής σάς αφαίρεσε",
    "An administrator removed {user}" : "Ένας διαχειριστής αφαίρεσε τον/την χρήστη {user}",
    "{actor} invited {federated_user}" : "Ο {actor} προσκάλεσε τον {federated_user}",
    "You invited {federated_user}" : "Προσκαλέσατε τον {federated_user}",
    "You accepted the invitation" : "Αποδεχθήκατε την πρόσκληση",
    "{actor} invited you" : "Ο {actor} σας προσκάλεσε",
    "An administrator invited you" : "Ένας διαχειριστής σας προσκάλεσε",
    "An administrator invited {federated_user}" : "Ένας διαχειριστής προσκάλεσε τον/την {federated_user}",
    "{federated_user} accepted the invitation" : "Ο/Η {federated_user} αποδέχθηκε την πρόσκληση",
    "{actor} removed {federated_user}" : "Ο/Η {actor} αφαίρεσε τον/την {federated_user}",
    "You removed {federated_user}" : "Αφαιρέσατε τον {federated_user}",
    "You declined the invitation" : "Απορρίψατε την πρόσκληση",
    "An administrator removed {federated_user}" : "Ένας διαχειριστής αφαίρεσε τον {federated_user}",
    "{federated_user} declined the invitation" : "Ο/Η {federated_user} απέρριψε την πρόσκληση",
    "{actor} added group {group}" : "Ο/Η {actor} πρόσθεσε την ομάδα {group}",
    "You added group {group}" : "Προσθέσατε την ομάδα {group}",
    "An administrator added group {group}" : "Ένας διαχειριστής πρόσθεσε την ομάδα {group}",
    "{actor} removed group {group}" : "Ο/Η {actor} αφαίρεσε την ομάδα {group}",
    "You removed group {group}" : "Αφαιρέσατε την ομάδα {group}",
    "An administrator removed group {group}" : "Ένας διαχειριστής αφαίρεσε την ομάδα {group}",
    "{actor} added team {circle}" : "Ο/Η {actor} πρόσθεσε την ομάδα {circle}",
    "You added team {circle}" : "Προσθέσατε την ομάδα {circle}",
    "An administrator added team {circle}" : "Ένας διαχειριστής πρόσθεσε την ομάδα {circle}",
    "{actor} removed team {circle}" : "Ο/Η {actor} αφαίρεσε την ομάδα {circle}",
    "You removed team {circle}" : "Αφαιρέσατε την ομάδα {circle}",
    "An administrator removed team {circle}" : "Ένας διαχειριστής αφαίρεσε την ομάδα {circle}",
    "{actor} added {phone}" : "Ο/Η {actor} πρόσθεσε {phone}",
    "You added {phone}" : "Προσθέσατε {phone}",
    "An administrator added {phone}" : "Ένας διαχειριστής πρόσθεσε {phone}",
    "{actor} removed {phone}" : "Ο/Η {actor} αφαίρεσε {phone}",
    "You removed {phone}" : "Αφαιρέσατε {phone}",
    "An administrator removed {phone}" : "Ένας διαχειριστής αφαίρεσε {phone}",
    "{actor} promoted {user} to moderator" : "Ο {actor} προήγαγε τον {user} σε συντονιστή",
    "You promoted {user} to moderator" : "Προάγατε τον {user} σε συντονιστή",
    "{actor} promoted you to moderator" : "Ο/Η {actor} σας προήγαγε σε συντονιστή",
    "An administrator promoted you to moderator" : "Ένας διαχειριστής σας προήγαγε σε συντονιστή",
    "An administrator promoted {user} to moderator" : "Ένας διαχειριστής προήγαγε τον/την {user} σε συντονιστή",
    "{actor} demoted {user} from moderator" : "Ο/Η {actor} υποβίβασε τον/την {user} από συντονιστή",
    "You demoted {user} from moderator" : "Υποβιβάσατε τον {user} από συντονιστή",
    "{actor} demoted you from moderator" : "Ο/Η {actor} σας υποβίβασε από συντονιστή",
    "An administrator demoted you from moderator" : "Ένας διαχειριστής σας υποβίβασε από συντονιστή",
    "An administrator demoted {user} from moderator" : "Ένας διαχειριστής υποβίβασε τον/την {user} από συντονιστή",
    "{actor} shared a file which is no longer available" : "Ο/Η {actor} διαμοίρασε ένα αρχείο που δεν είναι πλέον διαθέσιμο",
    "You shared a file which is no longer available" : "Διαμοιράσε αρχείο που δεν είναι πλέον διαθέσιμο",
    "File shares are currently not supported in federated conversations" : "Οι κοινόχρηστοι αρχείων δεν υποστηρίζονται προς το παρόν σε federated συνομιλίες",
    "The shared location is malformed" : "Η κοινόχρηστη τοποθεσία είναι κακοσχηματισμένη",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "Ο {actor} ρύθμισε το Matterbridge για συγχρονισμό αυτής της συνομιλίας με άλλες συνομιλίες",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Ρυθμίσατε το Matterbridge για συγχρονισμό αυτής της συνομιλίας με άλλες συνομιλίες",
    "{actor} created thread {title}" : "Ο/Η {actor} δημιούργησε το νήμα {title}",
    "You created thread {title}" : "Δημιουργήσατε το νήμα {title}",
    "{actor} renamed thread {title}" : "Ο/Η {actor} μετονόμασε το νήμα {title}",
    "You renamed thread {title}" : "Μετονομάσατε το νήμα {title}",
    "{actor} updated the Matterbridge configuration" : "Ο/Η {actor} ενημέρωσε τη ρύθμιση του Matterbridge",
    "You updated the Matterbridge configuration" : "Ενημερώσατε τη ρύθμιση του Matterbridge",
    "{actor} removed the Matterbridge configuration" : "Ο/Η {actor} αφαίρεσε τη ρύθμιση του Matterbridge",
    "You removed the Matterbridge configuration" : "Αφαιρέσατε τη ρύθμιση του Matterbridge",
    "{actor} started Matterbridge" : "Ο/Η {actor} ξεκίνησε το Matterbridge",
    "You started Matterbridge" : "Ξεκινήσατε το Matterbridge",
    "{actor} stopped Matterbridge" : "Ο/Η {actor} σταμάτησε το Matterbridge",
    "You stopped Matterbridge" : "Σταματήσατε το Matterbridge",
    "{actor} deleted a message" : "Ο/Η {actor} διέγραψε ένα μήνυμα",
    "You deleted a message" : "Διαγράψατε ένα μήνυμα",
    "{actor} edited a message" : "Ο/Η {actor} επεξεργάστηκε ένα μήνυμα",
    "You edited a message" : "Επεξεργαστήκατε ένα μήνυμα",
    "{actor} deleted a reaction" : "Ο/Η {actor} διέγραψε μια αντίδραση",
    "You deleted a reaction" : "Διαγράψατε μια αντίδραση",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Ορίσατε τη λήξη μηνύματος σε %n εβδομάδα","Ορίσατε τη λήξη μηνύματος σε %n εβδομάδες"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Ορίσατε τη λήξη μηνύματος σε %n ημέρα","Ορίσατε τη λήξη μηνύματος σε %n ημέρες"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Ορίσατε τη λήξη μηνύματος σε %n ώρα","Ορίσατε τη λήξη μηνύματος σε %n ώρες"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Ορίσατε τη λήξη μηνύματος σε %n λεπτό","Ορίσατε τη λήξη μηνύματος σε %n λεπτά"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n εβδομάδα","Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n εβδομάδες"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n ημέρα","Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n ημέρες"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n ώρα","Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n ώρες"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n λεπτό","Ο/Η {actor} όρισε τη λήξη μηνύματος σε %n λεπτά"],
    "{actor} disabled message expiration" : "Ο/Η {actor} απενεργοποίησε τη λήξη μηνυμάτων",
    "You disabled message expiration" : "Απενεργοποιήσατε τη λήξη μηνυμάτων",
    "{actor} cleared the history of the conversation" : "Ο/Η {actor} εκκαθάρισε το ιστορικό της συνομιλίας",
    "You cleared the history of the conversation" : "Εκκαθαρίσατε το ιστορικό της συνομιλίας",
    "{actor} set the conversation picture" : "Ο/Η {actor} όρισε την εικόνα συνομιλίας",
    "You set the conversation picture" : "Ορίσατε την εικόνα συνομιλίας",
    "{actor} removed the conversation picture" : "Ο/Η {actor} αφαίρεσε την εικόνα συνομιλίας",
    "You removed the conversation picture" : "Αφαιρέσατε την εικόνα συνομιλίας",
    "{actor} ended the poll {poll}" : "Ο/Η {actor} τερμάτισε τη δημοσκόπηση {poll}",
    "You ended the poll {poll}" : "Τερματίσατε τη δημοσκόπηση {poll}",
    "{actor} started the video recording" : "Ο/Η {actor} ξεκίνησε την εγγραφή βίντεο",
    "You started the video recording" : "Ξεκινήσατε την εγγραφή βίντεο",
    "{actor} stopped the video recording" : "Ο/Η {actor} σταμάτησε την εγγραφή βίντεο",
    "You stopped the video recording" : "Σταματήσατε την εγγραφή βίντεο",
    "{actor} started the audio recording" : "Ο/Η {actor} ξεκίνησε την εγγραφή ήχου",
    "You started the audio recording" : "Ξεκινήσατε την εγγραφή ήχου",
    "{actor} stopped the audio recording" : "Ο/Η {actor} σταμάτησε την εγγραφή ήχου",
    "You stopped the audio recording" : "Σταματήσατε την εγγραφή ήχου",
    "The recording failed" : "Η εγγραφή απέτυχε",
    "Someone voted on the poll {poll}" : "Κάποιος ψήφισε στη δημοσκόπηση {poll}",
    "Message deleted by author" : "Το μήνυμα διαγράφηκε από τον συντάκτη",
    "Message deleted by {actor}" : "Το μήνυμα διαγράφηκε από {actor}",
    "Message deleted by you" : "Το μήνυμα διαγράφηκε από εσάς",
    "Deleted user" : "Διαγραμμένος χρήστης",
    "Unknown number" : "Άγνωστος αριθμός",
    "Administration" : "Διαχείριση",
    "System" : "Συστήματος",
    "%s (guest)" : "%s (επισκέπτης)",
    "Missed call" : "Αναπάντητη κλήση",
    "Unanswered call" : "Αναπάντητη κλήση",
    "Call ended (Duration {duration})" : "Κλήση τερματίστηκε (Διάρκεια {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "{actor} ended the call (Duration {duration})" : "Ο {actor} τερμάτισε την κλήση (Διάρκεια {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Η κλήση με %n επισκέπτη τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})","Η κλήση με %n επισκέπτες τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Κλήση με %n επισκέπτη τερματίστηκε (Διάρκεια {duration})","Κλήση με %n επισκέπτες τερματίστηκε (Διάρκεια {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["Ο {actor} τερμάτισε την κλήση με %n επισκέπτη (Διάρκεια {duration})","Ο {actor} τερμάτισε την κλήση με %n επισκέπτες (Διάρκεια {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση με τον {user1} τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "Call with {user1} ended (Duration {duration})" : "Κλήση με τον {user1} τερματίστηκε (Διάρκεια {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "Ο {actor} τερμάτισε την κλήση με τον {user1} (Διάρκεια {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση με τους {user1} και {user2} τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Κλήση με τους {user1} και {user2} τερματίστηκε (Διάρκεια {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "Ο {actor} τερμάτισε την κλήση με τους {user1} και {user2} (Διάρκεια {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση με τους {user1}, {user2} και {user3} τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Κλήση με τους {user1}, {user2} και {user3} τερματίστηκε (Διάρκεια {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "Ο {actor} τερμάτισε την κλήση με τους {user1}, {user2} και {user3} (Διάρκεια {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση με τους {user1}, {user2}, {user3} και {user4} τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Κλήση με τους {user1}, {user2}, {user3} και {user4} τερματίστηκε (Διάρκεια {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Ο {actor} τερμάτισε την κλήση με τους {user1}, {user2}, {user3} και {user4} (Διάρκεια {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Η κλήση με τους {user1}, {user2}, {user3}, {user4} και {user5} τερματίστηκε, καθώς έφτασε τη μέγιστη διάρκεια κλήσης (Διάρκεια {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Κλήση με τους {user1}, {user2}, {user3}, {user4} και {user5} τερματίστηκε (Διάρκεια {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Ο/Η {actor} τερμάτισε την κλήση με τους {user1}, {user2}, {user3}, {user4} και {user5} (Διάρκεια {duration})",
    "Message of {user} in {conversation}" : "Μήνυμα του {user} στην {conversation}",
    "Message of {user}" : "Μήνυμα του {user}",
    "Message of a deleted user in {conversation}" : "Μήνυμα διαγεγραμμένου χρήστη στην {conversation}",
    "Talk conversations" : "Συνομιλίες με Talk",
    "Talk to %s" : "Talk σε %s",
    "An error occurred. Please contact your administrator." : "Παρουσιάστηκε σφάλμα. Παρακαλώ επικοινωνήστε με τον διαχειριστή σας.",
    "File not found" : "Το αρχείο δεν βρέθηκε",
    "File is not shared, or shared but not with the user" : "Το αρχείο δεν είναι κοινόχρηστο, ή δεν μοιράζεται με τον χρήστη",
    "No account available to delete." : "Δεν υπάρχει διαθέσιμος λογαριασμός για διαγραφή.",
    "Poll" : "Δημοσκόπηση",
    "Password needs to be set" : "Απαιτείται ορισμός συνθηματικού",
    "Uploading the file failed" : "Η μεταφόρτωση του αρχείου απέτυχε",
    "No image file provided" : "Δεν παρέχεται αρχείο εικόνας",
    "File is too big" : "Το αρχείο είναι πολύ μεγάλο",
    "Invalid file provided" : "Έχει δοθεί μη έγκυρο αρχείο",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "Talk mentions" : "Αναφορές σε ονόματα του Talk",
    "More conversations" : "Περισσότερες συνομιλίες",
    "Say hi to your friends and colleagues!" : "Πείτε γειά σε φίλους και συνεργάτες!",
    "No unread mentions" : "Δεν υπάρχουν μη αναγνωσμένες αναφορές στο όνομά σας",
    "Call in progress" : "Κλήση σε εξέλιξη",
    "You were mentioned" : "Αναφέρθηκε το όνομά σας",
    "Write to conversation" : "Γράψτε στη συνομιλία",
    "Writes event information into a conversation of your choice" : "Γράφει πληροφορίες εκδήλωσης μιας συνομιλίας επιλογής σας",
    "Missing email field in header line" : "Λείπει το πεδίο email στην γραμμή κεφαλίδας",
    "Following lines are invalid: %s" : "Οι ακόλουθες γραμμές είναι μη έγκυρες: %s",
    "%1$s invited you to conversation \"%2$s\"." : "Ο %1$s σας προσκάλεσε στη συνομιλία \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Προσκληθήκατε στη συνομιλία \"%s\".",
    "Conversation invitation" : "Πρόσκληση συζήτησης",
    "Scheduled time" : "Προγραμματισμένη ώρα",
    "Description" : "Περιγραφή",
    "You can also dial-in via phone with the following details" : "Μπορείτε επίσης να καλέσετε μέσω τηλεφώνου με τις ακόλουθες λεπτομέρειες.",
    "Dial-in information" : "Πληροφορίες κλήσης",
    "Meeting ID" : "Αναγνωριστικό Meeting ",
    "Your PIN" : "Το PIN σας",
    "Click the button below to join the lobby now." : "Κάντε κλικ στο παρακάτω κουμπί για να συμμετάσχετε τώρα στην αίθουσα αναμονής.",
    "Click the link below to join the lobby now." : "Κάντε κλικ στον παρακάτω σύνδεσμο για να συμμετάσχετε τώρα στην αίθουσα αναμονής.",
    "Join lobby for \"%s\"" : "Συμμετοχή στην αιθουσα αναμονής για \"%s\"",
    "Click the button below to join the conversation now." : "Κάντε κλικ στο παρακάτω κουμπί για να συμμετάσχετε τώρα στη συνομιλία.",
    "Click the link below to join the conversation now." : "Κάντε κλικ στον παρακάτω σύνδεσμο για να συμμετάσχετε τώρα στη συνομιλία.",
    "Join \"%s\"" : "Συμμετοχή στο \"%s\"",
    "Meeting" : "Συνάντηση",
    "Password request: %s" : "Αίτημα κωδικού πρόσβασης: %s",
    "Private conversation" : "Ιδιωτική συνομιλία",
    "Deleted user (%s)" : "Διεγραμμένος χρήστης (%s)",
    "Failed to upload call recording" : "Αποτυχία μεταφόρτωσης εγγραφής κλήσης",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Ο διακομιστής εγγραφής απέτυχε να μεταφορτώσει την εγγραφή της κλήσης {call}. Παρακαλώ επικοινωνήστε με τη διαχείριση.",
    "Share to chat" : "Κοινή χρήση στη συνομιλία",
    "Dismiss notification" : "Αποδέσμευση ειδοποίησης",
    "Call recording now available" : "Η εγγραφή κλήσης είναι πλέον διαθέσιμη",
    "The recording for the call in {call} was uploaded to {file}." : "Η εγγραφή για την κλήση στο {call} μεταφορτώθηκε στο {file}.",
    "Transcript now available" : "Η μεταγραφή είναι πλέον διαθέσιμη",
    "The transcript for the call in {call} was uploaded to {file}." : "Η μεταγραφή για την κλήση στο {call} μεταφορτώθηκε στο {file}.",
    "Failed to transcript call recording" : "Αποτυχία μεταγραφής εγγραφής κλήσης",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Ο διακομιστής απέτυχε να μεταγράψει την εγγραφή στο {file} για την κλήση στο {call}. Παρακαλώ επικοινωνήστε με τη διαχείριση.",
    "Call summary now available" : "Η σύνοψη κλήσης είναι πλέον διαθέσιμη",
    "The summary for the call in {call} was uploaded to {file}." : "Η σύνοψη για την κλήση στο {call} μεταφορτώθηκε στο {file}.",
    "Failed to summarize call recording" : "Αποτυχία σύνταξης σύνοψης εγγραφής κλήσης",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Ο διακομιστής απέτυχε να συνοψίσει την εγγραφή στο {file} για την κλήση στο {call}. Παρακαλώ επικοινωνήστε με τη διαχείριση.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "Ο {user1} σας προσκάλεσε να συμμετάσχετε στο {roomName} στον {remoteServer}",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "{user1} invited you to a federated conversation" : "Ο {user1} σας προσκάλεσε σε μια federated συνομιλία",
    "Someone reacted" : "Κάποιος αντέδρασε",
    "New message" : "Νέο μήνυμα",
    "Reminder" : "Υπενθύμιση",
    "Someone mentioned you" : "Κάποιος σας ανέφερε",
    "Notification" : "Ειδοποίηση",
    "Someone reacted in a private conversation" : "Κάποιος αντέδρασε σε μια ιδιωτική συνομιλία",
    "You received a message in a private conversation" : "Λάβατε ένα μήνυμα σε μια ιδιωτική συνομιλία",
    "Reminder in a private conversation" : "Υπενθύμιση σε μια ιδιωτική συνομιλία",
    "Someone mentioned you in a private conversation" : "Κάποιος σας ανέφερε σε μια ιδιωτική συνομιλία",
    "Notification in a private conversation" : "Ειδοποίηση σε μια ιδιωτική συνομιλία",
    "Reminder: You in {call}" : "Υπενθύμιση: Εσείς στο {call}",
    "Reminder: {user} in {call}" : "Υπενθύμιση: {user} στο {call}",
    "Reminder: Deleted user in {call}" : "Υπενθύμιση: Διεγραμμένος χρήστης στο {call}",
    "Reminder: {guest} (guest) in {call}" : "Υπενθύμιση: {guest} (επισκέπτης) στο {call}",
    "Reminder: Guest in {call}" : "Υπενθύμιση: Επισκέπτης στο {call}",
    "{user} reacted with {reaction}" : "Ο/Η {user} αντέδρασε με {reaction}",
    "{user} reacted with {reaction} in {call}" : "Ο/Η {user} αντέδρασε με {reaction} στο {call}",
    "Deleted user reacted with {reaction} in {call}" : "Διεγραμμένος χρήστης αντέδρασε με {reaction} στο {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "Ο/Η {guest} (επισκέπτης) αντέδρασε με {reaction} στο {call}",
    "Guest reacted with {reaction} in {call}" : "Επισκέπτης αντέδρασε με {reaction} στο {call}",
    "{user} in {call}" : "Ο/Η {user} είναι σε {call}",
    "Deleted user in {call}" : "Διαγράφηκε ο χρήστης στην {call}",
    "{guest} (guest) in {call}" : "{guest} (επισκέπτης) στην {call}",
    "Guest in {call}" : "Επισκέπτης στην {call}",
    "{user} sent you a private message" : "Ο/Η {user} σας έστειλε προσωπικό μήνυμα",
    "{user} sent a message in conversation {call}" : "Ο/Η {user} έστειλε μήνυμα στην συζήτηση {call}",
    "A deleted user sent a message in conversation {call}" : "Ένας διεγραμένος χρήστης έστειλε μήνυμα στην συνομιλία {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (επισκέπτης) έστειλε μήνυμα στην συζήτηση {call}",
    "A guest sent a message in conversation {call}" : "Ένας επισκέπτης έστειλε μήνυμα σε μια συνομιλία {call}",
    "{user} replied to your private message" : "Ο/Η {user} απάντησε στο προσωπικό μήνυμα σας",
    "{user} replied to your message in conversation {call}" : "Ο/Η {user} απάντησε στο μήνυμά σας στην συζήτηση {call}",
    "A deleted user replied to your message in conversation {call}" : "Ένας διεγραμένος χρήστης απάντησε στο μήνυμά σας στην συζήτηση {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (επισκέπτης) απάντησε στο μήνυμα σας στην συζήτηση {call}",
    "A guest replied to your message in conversation {call}" : "Ένας επισκέπτης απάντησε στο μήνυμα σας στην συζήτηση {call}",
    "Reminder: You in private conversation {call}" : "Υπενθύμιση: Εσείς σε ιδιωτική συνομιλία {call}",
    "Reminder: A deleted user in private conversation {call}" : "Υπενθύμιση: Διεγραμμένος χρήστης σε ιδιωτική συνομιλία {call}",
    "Reminder: {user} in private conversation" : "Υπενθύμιση: {user} σε ιδιωτική συνομιλία",
    "Reminder: You in conversation {call}" : "Υπενθύμιση: Εσείς σε συνομιλία {call}",
    "Reminder: {user} in conversation {call}" : "Υπενθύμιση: {user} σε συνομιλία {call}",
    "Reminder: A deleted user in conversation {call}" : "Υπενθύμιση: Διεγραμμένος χρήστης σε συνομιλία {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Υπενθύμιση: {guest} (επισκέπτης) σε συνομιλία {call}",
    "Reminder: A guest in conversation {call}" : "Υπενθύμιση: Επισκέπτης σε συνομιλία {call}",
    "{user} reacted with {reaction} to your private message" : "Ο/Η {user} αντέδρασε με {reaction} στο προσωπικό σας μήνυμα",
    "{user} reacted with {reaction} to your message in conversation {call}" : "Ο/Η {user} αντέδρασε με {reaction} στο μήνυμά σας στη συνομιλία {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Ένας διεγραμμένος χρήστης αντέδρασε με {reaction} στο μήνυμά σας στη συνομιλία {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "Ο/Η {guest} (επισκέπτης) αντέδρασε με {reaction} στο μήνυμά σας στη συνομιλία {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Ένας επισκέπτης αντέδρασε με {reaction} στο μήνυμά σας στη συνομιλία {call}",
    "{user} mentioned you in a private conversation" : "Ο/Η {user} σας ανέφερε σε μια ιδιωτική συνομιλία",
    "{user} mentioned group {group} in conversation {call}" : "Ο/Η {user} ανέφερε την ομάδα {group} στη συνομιλία {call}",
    "{user} mentioned team {team} in conversation {call}" : "Ο/Η {user} ανέφερε την ομάδα {team} στη συνομιλία {call}",
    "{user} mentioned everyone in conversation {call}" : "Ο/Η {user} ανέφερε όλους στη συνομιλία {call}",
    "{user} mentioned you in conversation {call}" : "Ο/Η {user} σας ανέφερε στη συνομιλία {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Ένας διεγραμμένος χρήστης ανέφερε την ομάδα {group} στη συνομιλία {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Ένας διεγραμμένος χρήστης ανέφερε την ομάδα {team} στη συνομιλία {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Ένας διεγραμμένος χρήστης ανέφερε όλους στη συνομιλία {call}",
    "A deleted user mentioned you in conversation {call}" : "Ένας διεγραμμένος χρήστης σας ανέφερε στη συνομιλία {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "Ο/Η {guest} (επισκέπτης) ανέφερε την ομάδα {group} στη συνομιλία {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "Ο/Η {guest} (επισκέπτης) ανέφερε την ομάδα {team} στη συνομιλία {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "Ο/Η {guest} (επισκέπτης) ανέφερε όλους στη συνομιλία {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "Ο/Η {guest} (επισκέπτης) σας ανέφερε στη συνομιλία {call}",
    "A guest mentioned group {group} in conversation {call}" : "Ένας επισκέπτης ανέφερε την ομάδα {group} στη συνομιλία {call}",
    "A guest mentioned team {team} in conversation {call}" : "Ένας επισκέπτης ανέφερε την ομάδα {team} στη συνομιλία {call}",
    "A guest mentioned everyone in conversation {call}" : "Ένας επισκέπτης ανέφερε όλους στη συνομιλία {call}",
    "A guest mentioned you in conversation {call}" : "Ένας επισκέπτης σας ανέφερε στη συνομιλία {call}",
    "View message" : "Προβολή μηνύματος",
    "Dismiss reminder" : "Αποδέσμευση υπενθύμισης",
    "View chat" : "Εμφάνιση συνομιλίας",
    "{user} invited you to a group conversation: {call}" : "Ο/Η {user} σας προσκάλεσε σε ομαδική κλήση: {call}",
    "Join call" : "Συμμετοχή σε κλήση",
    "Answer call" : "Απάντηση κλήσης",
    "{user} would like to talk with you" : "Ο/Η {user} θα ήθελε να μιλήσει μαζί σας",
    "Call back" : "Επιστροφή κλήσης",
    "You missed a call from {user}" : "Αναπάντητη κλήση από τον {user}",
    "Accept call" : "Αποδοχή κλήσης",
    "Incoming phone call from {call}" : "Εισερχόμενη τηλεφωνική κλήση από {call}",
    "You missed a phone call from {call}" : "Χάσατε μια τηλεφωνική κλήση από {call}",
    "A group call has started in {call}" : "Ξεκίνησε ομαδική κλήση σε {call}",
    "You missed a group call in {call}" : "Αναπάντητη από ομαδική κλήση {call}",
    "{email} is requesting the password to access {file}" : "Αίτηση από το {email} για κωδικό πρόσβασης στο {file}",
    "{email} tried to request the password to access {file}" : "Προσπάθεια αίτησης από το {email} για κωδικό πρόσβασης στο {file}",
    "Someone is requesting the password to access {file}" : "Κάποιος αιτήθηκε κωδικό πρόσβασης για το {file}",
    "Someone tried to request the password to access {file}" : "Κάποιος προσπαθεί να αιτηθεί κωδικό πρόσβασης για το {file}",
    "Open settings" : "Άνοιγμα ρυθμίσεων",
    "Hosted signaling server added" : "Προστέθηκε φιλοξενούμενος διακομιστής σηματοδότησης",
    "The hosted signaling server is now configured and will be used." : "Ο φιλοξενούμενος διακομιστής σηματοδότησης έχει πλέον ρυθμιστεί και θα χρησιμοποιηθεί.",
    "Hosted signaling server removed" : "Αφαιρέθηκε φιλοξενούμενος διακομιστής σηματοδότησης",
    "The hosted signaling server was removed and will not be used anymore." : "Ο φιλοξενούμενος διακομιστής σηματοδότησης καταργήθηκε και δεν θα χρησιμοποιείται πλέον.",
    "Hosted signaling server changed" : "Άλλαξε ο φιλοξενούμενος διακομιστής σηματοδότησης",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Ο λογαριασμός του φιλοξενούμενου διακομιστή σηματοδότησης άλλαξε την κατάσταση από \"{oldstatus}\" σε \"{newstatus}\".",
    "pending" : "εκκρεμεί",
    "active" : "ενεργό",
    "expired" : "έληξε",
    "blocked" : "αποκλεισμένο",
    "error" : "σφάλμα",
    "The certificate of {host} expires in {days} days" : "Το πιστοποιητικό του {host} λήγει σε {days} ημέρες",
    "The certificate of {host} expired" : "Το πιστοποιητικό του {host} έληξε",
    "Contact via Talk" : "Επικοινωνία μέσω Talk",
    "Open Talk" : "Άνοιγμα του Talk",
    "Default" : "Προεπιλεγμένο",
    "Presentation" : "Παρουσίαση",
    "Conversations" : "Συνομιλίες",
    "Messages in current conversation" : "Μηνύματα στην τρέχουσα συνομιλία",
    "{user}" : "{user}",
    "Messages" : "Μηνύματα",
    "{user} in {conversation}" : "Υπάρχουν {user} στην συνομιλία {conversation}",
    "Messages in other conversations" : "Μηνύματα σε άλλες συνομιλίες",
    "One-to-one rooms always need to show the other users avatar" : "Τα δωμάτια ένα προς ένα πρέπει πάντα να εμφανίζουν το άβαταρ του άλλου χρήστη",
    "Invalid emoji character" : "Μη έγκυρος χαρακτήρας emoji",
    "Invalid background color" : "Μη έγκυρο χρώμα φόντου",
    "Avatar image is not square" : "Η εικόνα του άβαταρ δεν είναι τετράγωνη",
    "Room {number}" : "Δωμάτιο {number}",
    "Other" : "Άλλο",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Η αίτηση για δοκιμή απέτυχε επειδή δεν ήταν δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Υπάρχει πρόβλημα με τον έλεγχο ταυτότητας αυτής της περίπτωσης. Ίσως δεν είναι προσβάσιμο από έξω για την επαλήθευση της διεύθυνσης URL του.",
    "Something unexpected happened." : "Κάτι απροσδόκητο συνέβη.",
    "The URL is invalid." : "Η διεύθυνση URL δεν είναι έγκυρη.",
    "An HTTPS URL is required." : "Απαιτείται διεύθυνση URL HTTPS.",
    "The email address is invalid." : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου δεν είναι έγκυρη.",
    "The language is invalid." : "Η γλώσσα δεν είναι έγκυρη.",
    "The country is invalid." : "Η χώρα δεν είναι έγκυρη.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Υπάρχει πρόβλημα με το αίτημα της δοκιμής. Ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "Too many requests are send from your servers address. Please try again later." : "Στέλνονται πάρα πολλά αιτήματα από τη διεύθυνση των διακομιστών σας. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "There is already a trial registered for this Nextcloud instance." : "Υπάρχει ήδη μια δοκιμαστική καταχώριση για αυτήν την περίπτωση του Nextcloud.",
    "Something unexpected happened. Please try again later." : "Κάτι απροσδόκητο συνέβη. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Η αίτηση για δοκιμή απέτυχε επειδή ο διακομιστής δοκιμής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Trial requested but failed to get account information. Please check back later." : "Ζητήθηκε δοκιμή αλλά απέτυχε να λάβει πληροφορίες λογαριασμού. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Υπάρχει πρόβλημα με τον έλεγχο ταυτότητας αυτού του αιτήματος. Ίσως δεν είναι προσβάσιμο από έξω για την επαλήθευση της διεύθυνσης URL του.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Η ανάκτησης πληροφοριών λογαριασμού απέτυχε επειδή ο δοκιμαστικός διακομιστής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Υπάρχει πρόβλημα με την ανάκτηση των πληροφοριών λογαριασμού. Παρακαλούμε ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "There is no such account registered." : "Δεν έχει καταχωρηθεί τέτοιος λογαριασμός.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Η ανάκτηση πληροφοριών λογαριασμού απέτυχε επειδή δεν είναι δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Η διαγραφή του λογαριασμού του φιλοξενούμενου διακομιστή σηματοδότησης απέτυχε. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Η διαγραφής του λογαριασμού απέτυχε επειδή ο δοκιμαστικός διακομιστής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Υπάρχει πρόβλημα με τη διαγραφή του λογαριασμού. Παρακαλούμε ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "Too many requests are sent from your servers address. Please try again later." : "Πάρα πολλά αιτήματα αποστέλλονται από τη διεύθυνση των διακομιστών σας. Παρακαλώ προσπαθήστε ξανά αργότερα.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Η διαγραφής του λογαριασμού απέτυχε επειδή δεν είναι δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Note to self" : "Σημείωση προς εμένα",
    "A place for your private notes, thoughts and ideas" : "Ένας χώρος για τις προσωπικές σας σημειώσεις, σκέψεις και ιδέες",
    "Transcript is AI generated and may contain mistakes" : "Η μεταγραφή δημιουργήθηκε από ΤΝ και μπορεί να περιέχει λάθη",
    "Summary is AI generated and may contain mistakes" : "Η σύνοψη δημιουργήθηκε από ΤΝ και μπορεί να περιέχει λάθη",
    "Let's get started!" : "Ας ξεκινήσουμε!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Το Nextcloud Talk** είναι μια ασφαλής, αυτο-φιλοξενούμενη πλατφόρμα επικοινωνίας που ενσωματώνεται απρόσκοπτα με το οικοσύστημα Nextcloud.\n\n#### Βασικά Χαρακτηριστικά του Nextcloud Talk:\n\n* Συνομιλία και ανταλλαγή μηνυμάτων σε ιδιωτικές και ομαδικές συνομιλίες\n* Κλήσεις φωνής και βίντεο\n* Κοινή χρήση αρχείων και ενσωμάτωση με άλλες εφαρμογές Nextcloud\n* Προσαρμόσιμες ρυθμίσεις συνομιλιών, συντονισμός και έλεγχος απορρήτου\n* Web, επιφάνεια εργασίας και κινητό (iOS και Android)\n* Ιδιωτική & ασφαλής επικοινωνία\n\n Μάθετε περισσότερα στην [τεκμηρίωση χρήστη](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Καλώς ήρθατε στο Nextcloud Talk\n\nΤο Nextcloud Talk είναι μια ιδιωτική και ισχυρή εφαρμογή ανταλλαγής μηνυμάτων που ενσωματώνεται με το Nextcloud. Συνομιλήστε σε ιδιωτικές ή ομαδικές συνομιλίες, συνεργαστείτε μέσω κλήσεων φωνής και βίντεο, οργανώστε webinars και εκδηλώσεις, προσαρμόστε τις συνομιλίες σας και πολλά άλλα.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Μορφοποιήστε κείμενα για να δημιουργήσετε πλούσια μηνύματα\n\nΣτο Nextcloud Talk, μπορείτε να χρησιμοποιήσετε σύνταξη Markdown για να μορφοποιήσετε τα μηνύματά σας. Για παράδειγμα, εφαρμόστε **έντονη** ή *πλάγια* μορφοποίηση, ή `επισημάνετε κείμενα ως κώδικα`. Μπορείτε ακόμα να δημιουργήσετε πίνακες και να προσθέσετε επικεφαλίδες στο κείμενό σας.\n\nΧρειάζεται να διορθώσετε ένα ορθογραφικό λάθος ή να αλλάξετε τη μορφοποίηση; Επεξεργαστείτε το μήνυμά σας κάνοντας κλικ στο \"Επεξεργασία μηνύματος\" στο μενού μηνύματος.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Προσθέστε συνημμένα και συνδέσμους\n\nΕπισυνάψτε αρχεία από το Nextcloud Hub σας χρησιμοποιώντας το κουμπί \"+\". Μοιραστείτε στοιχεία από τα Αρχεία και διάφορες εφαρμογές Nextcloud. Ορισμένες εφαρμογές υποστηρίζουν ακόμα και διαδραστικά widgets, για παράδειγμα, η εφαρμογή Κείμενο.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Αφήστε τις συνομιλίες να ρέουν: αναφέρετε χρήστες, αντιδράστε σε μηνύματα και άλλα\n\nΜπορείτε να αναφέρετε όλους στη συνομιλία χρησιμοποιώντας %s ή να αναφέρετε συγκεκριμένους συμμετέχοντες πληκτρολογώντας \"@\" και επιλέγοντας το όνομά τους από τη λίστα.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Μπορείτε να απαντήσετε σε μηνύματα, να τα προωθήσετε σε άλλες συνομιλίες και άτομα, ή να αντιγράψετε το περιεχόμενο μηνύματος.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Κάντε περισσότερα με τον Έξυπνο Επιλογέα\n\nΑπλώς πληκτρολογήστε \"/\" ή μεταβείτε στο μενού \"+\" για να ανοίξετε τον Έξυπνο Επιλογέα όπου μπορείτε να επισυνάψετε διάφορο περιεχόμενο στα μηνύματά σας. Μπορείτε να ρυθμίσετε τον Έξυπνο Επιλογέα για να μπορείτε να προσθέτετε στοιχεία από εφαρμογές Nextcloud, GIFs, τοποθεσίες χαρτών, περιεχόμενο που δημιουργήθηκε από ΤΝ και πολλά άλλα.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Διαχείριση ρυθμίσεων συνομιλιών\n\nΣτο μενού συνομιλίας, μπορείτε να αποκτήσετε πρόσβαση σε διάφορες ρυθμίσεις για τη διαχείριση των συνομιλιών σας, όπως:\n* Επεξεργασία πληροφοριών συνομιλίας\n* Διαχείριση ειδοποιήσεων\n* Εφαρμογή πολυάριθμων κανόνων συντονισμού\n* Ρύθμιση πρόσβασης και ασφάλειας\n* Ενεργοποίηση bots\n* και πολλά άλλα!",
    "Andorra" : "Ανδόρα",
    "United Arab Emirates" : "Ηνωμένα Αραβικά Εμιράτα",
    "Afghanistan" : "Αφγανιστάν",
    "Antigua and Barbuda" : "Αντίκουα και Μπαρμπούντα",
    "Anguilla" : "Anguilla",
    "Albania" : "Αλβανία",
    "Armenia" : "Αρμενία",
    "Angola" : "Αγκόλα",
    "Antarctica" : "Ανταρκτική",
    "Argentina" : "Αργεντινή",
    "American Samoa" : "Αμερικανική Σαμόα",
    "Austria" : "Αυστρία",
    "Australia" : "Αυστραλία",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Αζερμπαϊτζάν",
    "Bosnia and Herzegovina" : "Βοσνία και Ερζεγοβίνη",
    "Barbados" : "Μπαρμπάντος",
    "Bangladesh" : "Μπαγκλαντές ",
    "Belgium" : "Βέλγιο",
    "Burkina Faso" : "Μπουρκίνα Φάσο",
    "Bulgaria" : "Βουλγαρία",
    "Bahrain" : "Μπαχρέιν",
    "Burundi" : "Μπουρούντι",
    "Benin" : "Μπενίν",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Βερμούδα",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Βολιβία, πολυεθνική πολιτεία της",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Βραζιλία",
    "Bahamas" : "Μπαχάμες",
    "Bhutan" : "Μπουτάν",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Μποτσουάνα",
    "Belarus" : "Λευκορωσία",
    "Belize" : "Μπελίσε",
    "Canada" : "Καναδάς",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Κονγκό, Λαϊκή Δημοκρατία του ",
    "Central African Republic" : "Δημοκρατία Κεντρικής Αφρικής",
    "Congo" : "Κονγκό",
    "Switzerland" : "Ελβετία",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Χιλή",
    "Cameroon" : "Καμερούν",
    "China" : "Κίνα",
    "Colombia" : "Κολομβία",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Κούβα",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Νησί των Χριστουγέννων",
    "Cyprus" : "Κύπρος",
    "Czechia" : "Czechia",
    "Germany" : "Γερμανία",
    "Djibouti" : "Djibouti",
    "Denmark" : "Δανία",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Αλγερία",
    "Ecuador" : "Εκουαδόρ",
    "Estonia" : "Εσθονία",
    "Egypt" : "Αίγυπτος",
    "Western Sahara" : "Δυτική Σαχάρα",
    "Eritrea" : "Eritrea",
    "Spain" : "Ισπανία",
    "Ethiopia" : "Αιθιοπία",
    "Finland" : "Φινλανδία",
    "Fiji" : "Φίτζι",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Micronesia, Federated States of" : "Μικρονησία, Ομοσπονδιακά κράτη του",
    "Faroe Islands" : "Νησιά Φερόε",
    "France" : "Γαλλία",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Ηνωμένο Βασίλειο της Μεγάλης Βρετανίας και Βορείου Ιρλανδίας",
    "Grenada" : "Γρενάδα",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Γκάμπια",
    "Guinea" : "Γουϊνέα",
    "Guadeloupe" : "Γουαδελούπη",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ελλάδα",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Γουατεμάλα",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Κροατία",
    "Haiti" : "Haiti",
    "Hungary" : "Ουγγαρία",
    "Indonesia" : "Ινδονησία",
    "Ireland" : "Ιρλανδία",
    "Israel" : "Ισραήλ",
    "Isle of Man" : "Isle of Man",
    "India" : "Ινδία",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Ιράκ",
    "Iran, Islamic Republic of" : "Ιράν, Ισλαμική Δημοκρατία του",
    "Iceland" : "Ισλανδία",
    "Italy" : "Ιταλία",
    "Jersey" : "Jersey",
    "Jamaica" : "Τζαμάικα",
    "Jordan" : "Ιορδανία",
    "Japan" : "Ιαπωνία",
    "Kenya" : "Κένυα",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Κορέα, Λαϊκή Δημοκρατία της",
    "Korea, Republic of" : "Δημοκρατία της Κορέας",
    "Kuwait" : "κουβέιτ",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Καζακστάν",
    "Lao People's Democratic Republic" : "Λαϊκή Δημοκρατία του Λάος",
    "Lebanon" : "Λίβανος",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Λιχτενστάιν",
    "Sri Lanka" : "Σρι Λάνκα",
    "Liberia" : "Λιβερία",
    "Lesotho" : "Λεσότο",
    "Lithuania" : "Λιθουανία",
    "Luxembourg" : "Λουξεμβούργο",
    "Latvia" : "Λετονία",
    "Libya" : "Λιβύη",
    "Morocco" : "Μαρόκο",
    "Monaco" : "Μονακό",
    "Moldova, Republic of" : "Δημοκρατία της Μολδαβίας",
    "Montenegro" : "Μαυροβούνιο",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Μαδαγασκάρη",
    "Marshall Islands" : "Marshall Islands",
    "North Macedonia" : "Δημοκρατία της Βόρειας Μακεδονίας",
    "Mali" : "Μάλι",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Μογγολία",
    "Macao" : "Μακάο",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Μαρτινίκα",
    "Mauritania" : "Μαυριτανία",
    "Montserrat" : "Montserrat",
    "Malta" : "Μάλτα",
    "Mauritius" : "Μαυρίκιος",
    "Maldives" : "Μαλδίβες",
    "Malawi" : "Μαλάουι",
    "Mexico" : "Μεξικό",
    "Malaysia" : "Μαλαισία",
    "Mozambique" : "Μοζαμβίκη",
    "Namibia" : "Ναμίμπια",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Νίγηρα",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Νιγηρία",
    "Nicaragua" : "Νικαράγουα",
    "Netherlands" : "Ολλανδία",
    "Norway" : "Νορβηγία",
    "Nepal" : "Νεπάλ",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Νέα Ζηλανδία",
    "Oman" : "Ομάν",
    "Panama" : "Παναμάς",
    "Peru" : "Περού",
    "French Polynesia" : "Γαλλική Πολυνησία",
    "Papua New Guinea" : "Παπούα Νέα Γουινέα",
    "Philippines" : "Φιλιππίνες",
    "Pakistan" : "Πακιστάν",
    "Poland" : "Πολωνία",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Πόρτο Ρίκο",
    "Palestine, State of" : "Παλαιστίνη, Κράτος της",
    "Portugal" : "Πορτογαλία",
    "Palau" : "Palau",
    "Paraguay" : "Παραγουάη",
    "Qatar" : "Κατάρ",
    "Réunion" : "Réunion",
    "Romania" : "Ρουμανία",
    "Serbia" : "Σερβία",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Ρουάντα",
    "Saudi Arabia" : "Σαουδική Αραβία",
    "Solomon Islands" : "Νησιά Σολομώντα",
    "Seychelles" : "Σεϊχέλες",
    "Sudan" : "Σουδάν",
    "Sweden" : "Σουηδία",
    "Singapore" : "Σιγκαπούρη",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Σλοβενία",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Σλοβακία",
    "Sierra Leone" : "Σιέρα Λεόνε",
    "San Marino" : "Σαν Μαρίνο",
    "Senegal" : "Σενεγάλη",
    "Somalia" : "Σομαλία",
    "Suriname" : "Σουρινάμ",
    "South Sudan" : "Νότιο Σουδάν",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "Ελ Σαλβαδόρ",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "French Southern Territories" : "Γαλλικά νότια εδάφη",
    "Togo" : "Togo",
    "Thailand" : "Ταϊλάνδη",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Τουρκμενιστάν",
    "Tunisia" : "Τυνησία",
    "Tonga" : "Tonga",
    "Turkey" : "Τουρκία",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Τουβάλου",
    "Taiwan, Province of China" : "Ταϊβάν, επαρχία της Κίνας",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ουκρανία",
    "Uganda" : "Ουγκάντα",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Ουρουγουάη",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Βενεζουέλα, Δημοκρατία της Βολιβίας της",
    "Virgin Islands, British" : "Παρθένοι Νήσοι, Βρετανικοί",
    "Virgin Islands, U.S." : "Παρθένοι Νήσοι, ΗΠΑ",
    "Viet Nam" : "Βιετνάμ",
    "Vanuatu" : "Βανουάτου",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Σαμόα",
    "Yemen" : "Υεμένη",
    "Mayotte" : "Mayotte",
    "South Africa" : "Νότιος Αφρική",
    "Zambia" : "Ζάμπια",
    "Zimbabwe" : "Ζιμπάμπουε",
    "Background blur" : "Θόλωση φόντου",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Δεν ήταν δυνατός ο έλεγχος υποστήριξης φόρτωσης WASM. Παρακαλώ ελέγξτε χειροκίνητα αν ο διακομιστής ιστού σας εξυπηρετεί αρχεία `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ο διακομιστής ιστού σας δεν είναι σωστά ρυθμισμένος για παράδοση αρχείων `.wasm`. Αυτό είναι τυπικά ένα ζήτημα με τη ρύθμιση του Nginx. Για τη θόλωση φόντου χρειάζεται μια προσαρμογή για να παραδίδει επίσης αρχεία `.wasm`. Συγκρίνετε τη ρύθμιση του Nginx σας με τη συνιστώμενη ρύθμιση στην τεκμηρίωσή μας.",
    "Talk configuration values" : "Τιμές ρύθμισης του Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Η εξαναγκασμένη διάρκεια κλήσης υποστηρίζεται μόνο με system cron. Παρακαλώ ενεργοποιήστε το system cron ή αφαιρέστε τη ρύθμιση `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Οι μικρές τιμές `max_call_duration` (τώρα ρυθμισμένες σε %d) δεν είναι επιβλητές λόγω τεχνικών περιορισμών. Η εργασία παρασκηνίου εκτελείται μόνο κάθε 5 λεπτά, οπότε χρησιμοποιήστε με δική σας ευθύνη.",
    "Federation" : "Federation",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Συνιστάται ιδιαίτερα η ρύθμιση του \"memcache.locking\" όταν το Talk Federation είναι ενεργοποιημένο.",
    "High-performance backend" : "Backend υψηλής απόδοσης",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Δεν έχει ρυθμιστεί backend υψηλής απόδοσης - Η λειτουργία του Nextcloud Talk χωρίς το backend υψηλής απόδοσης κλιμακώνεται μόνο για πολύ μικρές κλήσεις (μέγ. 2-3 συμμετέχοντες). Παρακαλώ ρυθμίστε το backend υψηλής απόδοσης για να διασφαλίσετε ότι οι κλήσεις με πολλαπλούς συμμετέχοντες λειτουργούν απρόσκοπτα.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Η λειτουργία \"conversation_cluster\" του backend υψηλής απόδοσης είναι παρωχημένη και δεν θα υποστηρίζεται πλέον στην επερχόμενη έκδοση. Το Backend υψηλής απόδοσης υποστηρίζει πραγματική συστοιχία σήμερα η οποία θα πρέπει να χρησιμοποιηθεί αντ' αυτού.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Ο ορισμός πολλαπλών backends υψηλής απόδοσης είναι παρωχημένος και δεν θα υποστηρίζεται πλέον στην επερχόμενη έκδοση. Αντ' αυτού, θα πρέπει να ρυθμιστεί ένας load-balancer μαζί με συστοιχία διακομιστών σηματοδότησης και να ρυθμιστεί στις ρυθμίσεις του Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Το αποθηκευμένο δημόσιο κλειδί για τον αλγόριθμο %1$s που χρησιμοποιείται δεν ταιριάζει με το αποθηκευμένο ιδιωτικό κλειδί. Εκτελέστε %2$s για να διορθώσετε το ζήτημα.",
    "High-performance backend not configured correctly. Run %s for details." : "Το backend υψηλής απόδοσης δεν είναι σωστά ρυθμισμένο. Εκτελέστε %s για λεπτομέρειες.",
    "High-performance backend not configured correctly" : "Το backend υψηλής απόδοσης δεν είναι σωστά ρυθμισμένο",
    "Error: Cannot connect to server" : "Σφάλμα: Αδυναμία σύνδεσης στο διακομιστή",
    "Error: Server did not respond with proper JSON" : "Σφάλμα: Ο διακομιστής ανταποκρίθηκε με λάθος JSON",
    "Error: Certificate expired" : "Σφάλμα: Το πιστοποιητικό έληξε",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Σφάλμα: Οι χρόνοι συστήματος του διακομιστή Nextcloud και του διακομιστή backend υψηλής απόδοσης δεν είναι συγχρονισμένοι. Παρακαλώ βεβαιωθείτε ότι και οι δύο διακομιστές είναι συνδεδεμένοι σε έναν διακομιστή χρόνου ή συγχρονίστε χειροκίνητα τον χρόνο τους.",
    "Could not get version" : "Δεν ήταν δυνατή η λήψη της έκδοσης",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Σφάλμα: Έκδοση που εκτελείται: {version}; Ο διακομιστής πρέπει να ενημερωθεί για να είναι συμβατός με αυτή την έκδοση του Talk",
    "Error: Server responded with: {error}" : "Σφάλμα: Ο διακομιστής απάντησε με: {error}",
    "Error: Unknown error occurred" : "Σφάλμα: Παρουσιάστηκε άγνωστο σφάλμα",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Προειδοποίηση: Έκδοση που εκτελείται: {version}; Ο διακομιστής δεν υποστηρίζει όλες τις λειτουργίες αυτής της έκδοσης Talk, λείπουν λειτουργίες: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Συνιστάται ιδιαίτερα η ρύθμιση μιας μνήμης cache όταν εκτελείτε το Nextcloud Talk με ένα backend υψηλής απόδοσης.",
    "Client Push" : "Client Push",
    "Recording backend" : "Backend εγγραφής",
    "Using the recording backend requires a High-performance backend." : "Η χρήση του backend εγγραφής απαιτεί ένα backend υψηλής απόδοσης.",
    "No recording backend configured" : "Δεν έχει ρυθμιστεί backend εγγραφής",
    "SIP configuration" : "Διαμόρφωση SIP",
    "Using the SIP functionality requires a High-performance backend." : "Η χρήση της λειτουργικότητας SIP απαιτεί ένα backend υψηλής απόδοσης.",
    "No SIP backend configured" : "Δεν έχει ρυθμιστεί backend SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή της ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Conversation not found" : "Η συζήτηση δεν βρέθηκε",
    "Path is already shared with this conversation" : "Η διαδρομή είναι ήδη κοινόχρηστη με αυτή τη συνομιλία",
    "Chat, video & audio-conferencing using WebRTC" : "Συνομιλία, βίντεο & διάσκεψη ήχου χρησιμοποιώντας WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Συνομιλία, βίντεο & διάσκεψη ήχου χρησιμοποιώντας WebRTC\n\n* 💬 **Συνομιλία** Το Nextcloud Talk έρχεται με μια απλή συνομιλία κειμένου, επιτρέποντάς σας να μοιραστείτε ή να μεταφορτώσετε αρχεία από την εφαρμογή Nextcloud Files ή την τοπική συσκευή σας και να αναφέρετε άλλους συμμετέχοντες.\n* 👥 **Ιδιωτικές, ομαδικές, δημόσιες και κωδικοπροστατευμένες κλήσεις!** Προσκαλέστε κάποιον, μια ολόκληρη ομάδα ή στείλτε έναν δημόσιο σύνδεσμο για πρόσκληση σε κλήση.\n* 🌐 **Federated συνομιλίες** Συνομιλήστε με άλλους χρήστες Nextcloud στους διακομιστές τους\n* 💻 **Κοινή χρήση οθόνης!** Μοιραστείτε την οθόνη σας με τους συμμετέχοντες της κλήσης σας.\n* 🚀 **Ενσωμάτωση με άλλες εφαρμογές Nextcloud** όπως Αρχεία, Ημερολόγιο, Κατάσταση χρήστη, Πίνακας ελέγχου, Flow, Χάρτες, Έξυπνος επιλογέας, Επαφές, Deck, και πολλά άλλα.\n* 🌉 **Συγχρονισμός με άλλες λύσεις συνομιλιών** Με το [Matterbridge](https://github.com/42wim/matterbridge/) να είναι ενσωματωμένο στο Talk, μπορείτε εύκολα να συγχρονίσετε πολλές άλλες λύσεις συνομιλιών με το Nextcloud Talk και αντίστροφα.",
    "Leave call" : "Αποχώρηση από την κλήση",
    "Navigating away from the page will leave the call in {conversation}" : "Η απομάκρυνση από την σελίδα θα αφήσει την κλήση σε {conversation}",
    "Stay in call" : "Παραμονή σε κλήση",
    "Error occurred when getting the conversation information" : "Παρουσιάστηκε σφάλμα κατά τη λήψη των πληροφοριών συνομιλίας",
    "Discuss this file" : "Συζήτηση γι αυτό το αρχείο",
    "Share this file with others to discuss it" : "Κοινή χρήση του αρχείου για σχολιασμό του",
    "Share this file" : "Κοινή χρήση του αρχείου",
    "Join conversation" : "Συμμετοχή στη συνομιλία",
    "This conversation is password-protected." : "Αυτή η συνομιλία προστατεύεται με κωδικό.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Εντοπίσαμε πολλές αποτυχημένες προσπάθειες εισαγωγής κωδικού από τη διεύθυνση IP σας. Για αυτό το λόγο, η επόμενη προσπάθειά σας θα καθυστερήσει έως και 30 δευτερόλεπτα.",
    "The password is wrong. Try again." : "Το συνθηματικό είναι λανθασμένο. Δοκιμάστε ξανά.",
    "Password" : "Συνθηματικό",
    "Submit" : "Υποβολή",
    "Error requesting the password." : ".Σφάλμα αίτησης κωδικού πρόσβασης.",
    "Request password" : "Αίτηση κωδικού πρόσβασης",
    "This conversation has ended" : "Η συνομιλία τερματίστηκε",
    "Error occurred when joining the conversation" : "Παρουσιάστηκε σφάλμα κατά τη συμμετοχή στη συνομιλία",
    "Close Talk sidebar" : "Κλείσιμο πλαϊνής γραμμής Talk",
    "Open Talk sidebar" : "Άνοιγμα πλαϊνής γραμμής Talk",
    "Everyone" : "Όλοι",
    "Users and moderators" : "Χρήστες και συντονιστές",
    "Moderators only" : "Συντονιστές μόνο",
    "Disable calls" : "Απενεργοποίηση κλήσεων",
    "Save changes" : "Αποθήκευση αλλαγών",
    "Saving …" : "Αποθηκεύεται …",
    "Saved!" : "Αποθηκεύτηκε!",
    "Limit to groups" : "Περιορισμός σε ομάδες",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Όταν επιλεγεί μία ομάδα, μόνο τα μέλη της μπορούν να συμμετέχουν.",
    "Guests can still join public conversations." : "Οι επισκέπτες μπορούν ακόμη να συμμετέχουν σε συνομιλίες.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Οι χρήστες που δεν μπορούν πλέον να χρησιμοποιήσουν το Talk θα παραμείνουν στη λίστα συμμετεχόντων στις προηγούμενες συνομιλίες τους και τα μηνύματα συνομιλίας τους θα διατηρηθούν.",
    "Limit using Talk" : "Περιορισμός χρήσης του Talk",
    "Limit creating a public and group conversation" : "Περιορισμός δημιουργίας δημόσιων και ομαδικών συζητήσεων",
    "Limit creating conversations" : "Περιορισμός δημιουργίας συζητήσεων",
    "Limit starting a call" : "Περιορισμός έναρξης κλήσης",
    "Limit starting calls" : "Περιορισμός έναρξης κλήσεων",
    "When a call has started, everyone with access to the conversation can join the call." : "Όταν ξεκινήσει μια κλήση, οποιοσδήποτε με πρόσβαση στην συνομιλία μπορεί να συμμετέχει στην κλήση.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Τα ακόλουθα bots είναι εγκατεστημένα σε αυτόν τον διακομιστή. Στην τεκμηρίωση μπορείτε να βρείτε λεπτομέρειες για το πώς να {linkstart1}δημιουργήσετε το δικό σας bot{linkend} ή μια {linkstart2}λίστα bots{linkend} για ενεργοποίηση στο διακομιστή σας.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Δεν υπάρχουν bots εγκατεστημένα σε αυτόν τον διακομιστή. Στην τεκμηρίωση μπορείτε να βρείτε λεπτομέρειες για το πώς να {linkstart1}δημιουργήσετε το δικό σας bot{linkend} ή μια {linkstart2}λίστα bots{linkend} για ενεργοποίηση στο διακομιστή σας.",
    "Description is not provided" : "Δεν παρέχεται περιγραφή",
    "Locked for moderators" : "Κλειδωμένο για συντονιστές",
    "Enabled" : "Ενεργοποιημένο",
    "Disabled" : "Απενεργοποιημένο",
    "Bots settings" : "Ρυθμίσεις bots",
    "State" : "Κατάσταση",
    "Name" : "Όνομα",
    "Last error" : "Τελευταίο σφάλμα",
    "Total errors count" : "Συνολικός αριθμός σφαλμάτων",
    "Find more bots" : "Εύρεση περισσότερων bots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Οι έμπιστοι διακομιστές μπορούν να ρυθμιστούν στη σελίδα {linkstart}ρυθμίσεων κοινής χρήσης{linkend}.",
    "Beta" : "Δοκιμαστικό",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Οι federated συνομιλίες και κλήσεις λειτουργούν ήδη. Η διαχείριση συνημμένων θα έρθει σε μια μελλοντική έκδοση.",
    "Enable Federation in Talk app" : "Ενεργοποίηση Federation στην εφαρμογή Talk",
    "Permissions" : "Δικαιώματα",
    "Allow users to be invited to federated conversations" : "Να επιτρέπεται στους χρήστες να προσκαλούνται σε federated συνομιλίες",
    "Allow users to invite federated users into conversation" : "Να επιτρέπεται στους χρήστες να προσκαλούν federated χρήστες σε συνομιλία",
    "Only allow to federate with trusted servers" : "Να επιτρέπεται η federation μόνο με έμπιστους διακομιστές",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Όταν επιλεγεί τουλάχιστον μία ομάδα, μόνο τα άτομα των καταχωρημένων ομάδων μπορούν να προσκαλούν federated χρήστες σε συνομιλίες.",
    "Groups allowed to invite federated users" : "Ομάδες που επιτρέπεται να προσκαλούν federated χρήστες",
    "Select groups …" : "Επιλογή ομάδων …",
    "All messages" : "Όλα τα μηνύματα",
    "@-mentions only" : "@-mentions μόνο",
    "Off" : "Απενεργοποίηση ",
    "General settings" : "Γενικές ρυθμίσεις",
    "Default notification settings" : "Προεπιλεγμένες ρυθμίσεις ειδοποιήσεων",
    "Default group notification" : "Προεπιλεγμένη ομάδα ειδοποιήσεων",
    "Default group notification for new groups" : "Προεπιλεγμένη ομάδα ειδοποιήσεων για νέες ομάδες",
    "Integration into other apps" : "Ενσωμάτωση σε άλλες εφαρμογές",
    "Allow conversations on files" : "Να επιτρέπονται συζητήσεις σε αρχεία",
    "Allow conversations on public shares for files" : "Να επιτρέπονται συνομιλίες για δημόσια διαμοιρασμένα αρχεία",
    "End-to-end encrypted calls" : "Κρυπτογραφημένες κλήσεις end-to-end",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Οι κρυπτογραφημένες κλήσεις end-to-end με ρυθμισμένη γέφυρα SIP απαιτούν νεότερη έκδοση του backend υψηλής απόδοσης και της γέφυρας SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Οι εφαρμογές για κινητές συσκευές προς το παρόν δεν υποστηρίζουν κρυπτογραφημένες κλήσεις από άκρο σε άκρο.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Κάνοντας κλικ στο κουμπί πάνω από τις πληροφορίες στη φόρμα γίνεται αποστολή στους διακομιστές της Struktur AG. Μπορείτε να βρείτε περισσότερες πληροφορίες στη διεύθυνση {linkstart}spreed.eu{linkend}.",
    "Pending" : "Εκκρεμεί",
    "Error" : "Σφάλμα",
    "Blocked" : "Αποκλεισμένος",
    "Active" : "Ενεργό",
    "Expired" : "Έληξε",
    "Never" : "Ποτέ",
    "The trial could not be requested. Please try again later." : "Δεν ήταν δυνατή η αίτηση της δοκιμής. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "The account could not be deleted. Please try again later." : "Δεν ήταν δυνατή η διαγραφή του λογαριασμού. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Hosted High-performance backend" : "Φιλοξενούμενο backend υψηλής απόδοσης",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Ο συνεργάτης μας Struktur AG παρέχει μια υπηρεσία όπου μπορεί να ζητηθεί ένας φιλοξενούμενος διακομιστής σηματοδότησης. Για αυτό πρέπει να συμπληρώσετε μόνο την παρακάτω φόρμα και το Nextcloud θα το ζητήσει. Μόλις ο διακομιστής ρυθμιστεί για εσάς, τα διαπιστευτήρια θα συμπληρωθούν αυτόματα. Αυτό θα αντικαταστήσει τις υπάρχουσες ρυθμίσεις διακομιστή σηματοδότησης.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Εάν ο λογαριασμός του backend υψηλής απόδοσής σας περιλαμβάνει λειτουργικότητα STUN και/ή TURN, οι ρυθμίσεις θα ενημερωθούν αναλόγως.",
    "URL of this Nextcloud instance" : "Διεύθυνση URL αυτής της εγκατάστασης Nextcloud",
    "Full name of the user requesting the trial" : "Πλήρες όνομα του χρήστη που αιτείται την δοκιμή",
    "Email of the user" : "Το email του χρήστη",
    "Language" : "Γλώσσα",
    "Country" : "Χώρα",
    "Request signaling server trial" : "Αίτηση δοκιμής διακομιστή σηματοδότησης",
    "You can see the current status of your hosted signaling server in the following table." : "Μπορείτε να δείτε την τρέχουσα κατάσταση του φιλοξενούμενου διακομιστή σηματοδότησης σας στον παρακάτω πίνακα.",
    "Status" : "Κατάσταση",
    "Created at" : "Έχει δημιουργηθεί στις",
    "Expires at" : "Λήγει στις",
    "Limits" : "Όρια",
    "STUN included" : "Ο STUN περιλαμβάνεται",
    "Yes" : "Ναι",
    "No" : "Όχι",
    "TURN included" : "Ο TURN περιλαμβάνεται",
    "Delete the signaling server account" : "Διαγραφή του λογαριασμού διακομιστή σηματοδότησης",
    "_%n user_::_%n users_" : ["%n χρήστης","%n χρήστες"],
    "Installed version: {version}" : "Εγκατεστημένη έκδοση: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Μπορείτε να εγκαταστήσετε το Matterbridge για να συνδέσετε το Nextcloud Talk με άλλες υπηρεσίες, επισκεφτείτε τη {linkstart1}σελίδα GitHub{linkend} τους για περισσότερες λεπτομέρειες. Η λήψη και η εγκατάσταση της εφαρμογής μπορεί να πάρει λίγο χρόνο. Σε περίπτωση που λήξει το χρονικό όριο, παρακαλώ εγκαταστήστε το χειροκίνητα από το {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Το δυαδικό Matterbridge έχει εσφαλμένα δικαιώματα. Παρακαλώ βεβαιωθείτε ότι το δυαδικό αρχείο Matterbridge ανήκει στον σωστό χρήστη και μπορεί να εκτελεστεί. Μπορεί να βρεθεί στο \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Το δυαδικό Matterbridge δεν βρέθηκε ή δεν ήταν δυνατό να εκτελεστεί.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Μπορείτε επίσης να ορίσετε τη διαδρομή προς το δυαδικό Matterbridge χειροκίνητα μέσω του config. Ανατρέξτε στην {linkstart} τεκμηρίωση ενσωμάτωσης Matterbridge {linkend} για περισσότερες πληροφορίες.",
    "Downloading …" : "Γίνεται λήψη ...",
    "Install Talk Matterbridge" : "Εγκατάσταση του Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Παρουσιάστηκε σφάλμα κατά την εγκατάσταση της εφαρμογής Matterbridge.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Παρουσιάστηκε σφάλμα κατά την εγκατάσταση της εφαρμογής Talk Matterbridge.Παρακαλούμε εγκαταστήστε την χειροκίνητα.",
    "Failed to execute Matterbridge binary." : "Η εκτέλεση του αλγόριθμου του Matterbridge επέτυχε.",
    "Matterbridge integration" : "Ενσωμάτωση του Matterbridge",
    "Enable Matterbridge integration" : "Ενεργοποίηση της ενσωμάτωσης του Matterbridge",
    "Status: Checking connection" : "Κατάσταση: Έλεγχος σύνδεσης",
    "OK: Running version: {version}" : "OK: Τρέχουσα έκδοση: {version}",
    "Error: Server seems to be a Signaling server" : "Σφάλμα: Ο διακομιστής φαίνεται να είναι διακομιστής σηματοδότησης",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Σφάλμα: Οι ώρες συστήματος του διακομιστή Nextcloud και του διακομιστή backend εγγραφής δεν είναι συγχρονισμένες. Βεβαιωθείτε ότι και οι δύο διακομιστές είναι συνδεδεμένοι σε έναν διακομιστή ώρας ή συγχρονίστε χειροκίνητα την ώρα τους.",
    "Recording backend URL" : "URL καταγραφής backend",
    "Validate SSL certificate" : "Επικυρώστε το πιστοποιητικό SSL",
    "Delete this server" : "Διαγραφή διακομιστή",
    "Test this server" : "Δοκιμή αυτού του διακομιστή",
    "Disabled for all calls" : "Απενεργοποιημένο για όλες τις κλήσεις",
    "Enabled for all calls" : "Ενεργοποιημένο για όλες τις κλήσεις",
    "Configurable on conversation level by moderators" : "Προσαρμόσιμο σε επίπεδο συνομιλίας από τους συντονιστές",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Οι ρυθμίσεις PHP \"upload_max_filesize\" ή \"post_max_size\" θα επιτρέψουν τη μεταφόρτωση αρχείων μέχρι {maxUpload}.",
    "Recording backend settings saved" : "Οι ρυθμίσεις του backend εγγραφής αποθηκεύτηκαν",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Οι συντονιστές θα επιτρέπεται να ενεργοποιούν τη συγκατάθεση σε επίπεδο συνομιλίας. Η συγκατάθεση για εγγραφή θα απαιτείται από κάθε συμμετέχοντα πριν από τη συμμετοχή σε κάθε κλήση σε αυτή τη συνομιλία.",
    "The consent to be recorded will be required for each participant before joining every call." : "Η συγκατάθεση για εγγραφή θα απαιτείται από κάθε συμμετέχοντα πριν από τη συμμετοχή σε κάθε κλήση.",
    "The consent to be recorded is not required." : "Δεν απαιτείται συγκατάθεση για εγγραφή.",
    "Recording backend configuration is only possible with a High-performance backend." : "Η ρύθμιση του backend εγγραφής είναι δυνατή μόνο με ένα backend υψηλής απόδοσης.",
    "Add a new recording backend server" : "Προσθήκη νέου διακομιστή backend εγγραφής",
    "Shared secret" : "Διαμοιρασμένο μυστικό",
    "Recording consent" : "Συγκατάθεση εγγραφής",
    "Recording transcription" : "Μεταγραφή εγγραφής",
    "Automatically transcribe call recordings with a transcription provider" : "Αυτόματη μεταγραφή εγγραφών κλήσεων με πάροχο μεταγραφής",
    "Automatically summarize call recordings with transcription and summary providers" : "Αυτόματη σύνταξη σύνοψης εγγραφών κλήσεων με παρόχους μεταγραφής και σύνοψης",
    "SIP configuration saved!" : "Η διαμόρφωση SIP αποθηκεύτηκε!",
    "SIP configuration is only possible with a High-performance backend." : "Η διαμόρφωση SIP είναι δυνατή μόνο με ένα backend υψηλής απόδοσης.",
    "Enable SIP Dial-out option" : "Ενεργοποίηση επιλογής SIP Dial-out",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Ο διακομιστής σηματοδότησης πρέπει να ενημερωθεί για να υποστηρίζει τη λειτουργία SIP Dial-out.",
    "Do not show SIP Dial-out caller number" : "Να μην εμφανίζεται ο αριθμός καλούντος SIP Dial-out",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Ο ανώνυμος αριθμός θα πρέπει να εμφανίζεται ως \"άγνωστος\" ή \"αποκλεισμένος αριθμός\" στον παραλήπτη της κλήσης",
    "Dial-out number" : "Αριθμός Dial-out",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Αριθμός μορφοποιημένος E164 που χρησιμοποιείται ως εφεδρικός αριθμός καλούντος για εξερχόμενες κλήσεις",
    "Dial-out prefix" : "Πρόθεμα Dial-out",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Πρόθεμα για τον ρυθμισμένο αριθμό χρήστη για εξερχόμενες κλήσεις (προεπιλογή είναι `+`)",
    "Restrict SIP configuration" : "Περιορίστε τη διαμόρφωση SIP",
    "Enable SIP configuration" : "Ενεργοποίηση διαμόρφωσης SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Μόνο οι χρήστες των ακόλουθων ομάδων μπορούν να ενεργοποιήσουν το SIP σε συνομιλίες που εποπτεύουν.",
    "Phone number (Country)" : "Αριθμός τηλεφώνου (Χώρα)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Αυτές οι πληροφορίες αποστέλλονται σε email πρόσκλησης καθώς και παρουσιάζονται στην πλευρική γραμμή σε όλους τους συμμετέχοντες.",
    "Nextcloud base URL" : "Βασική διεύθυνση URL Nextcloud",
    "Talk Backend URL" : "Διεύθυνση URL Backend Talk",
    "WebSocket URL" : "Διεύθυνση URL WebSocket",
    "Available features" : "Διαθέσιμες λειτουργίες",
    "Error: Websocket connection failed" : "Σφάλμα: Αποτυχία σύνδεσης WebSocket",
    "Error code" : "Σφάλμα κωδικού",
    "Error message" : "Μήνυμα σφάλματος",
    "Error: Websocket connection failed. Check browser console" : "Σφάλμα: Αποτυχία σύνδεσης WebSocket. Ελέγξτε την κονσόλα του προγράμματος περιήγησης",
    "High-performance backend URL" : "Διεύθυνση URL backend υψηλής απόδοσης",
    "Missing High-performance backend warning hidden" : "Η προειδοποίηση για το ελλειπόμενο backend υψηλής απόδοσης αποκρύφθηκε",
    "High-performance backend settings saved" : "Οι ρυθμίσεις του backend υψηλής απόδοσης αποθηκεύτηκαν",
    "Nextcloud Talk setup not complete" : "Η ρύθμιση του Nextcloud Talk δεν είναι πλήρης",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Παρακαλώ σημειώστε ότι σε κλήσεις με περισσότερους από 2 συμμετέχοντες χωρίς το backend υψηλής απόδοσης, οι συμμετέχοντες πιθανότατα θα αντιμετωπίσουν προβλήματα σύνδεσης και θα προκαλέσουν υψηλό φόρτο στις συμμετέχουσες συσκευές.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Εγκαταστήστε το backend υψηλής απόδοσης για να διασφαλίσετε ότι οι κλήσεις με πολλαπλούς συμμετέχοντες λειτουργούν απρόσκοπτα.",
    "Nextcloud portal" : "Πύλη Nextcloud",
    "Quick installation guide" : "Γρήγορος οδηγός εγκατάστασης",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Το backend υψηλής απόδοσης απαιτείται για κλήσεις και συνομιλίες με πολλαπλούς συμμετέχοντες. Χωρίς το backend, όλοι οι συμμετέχοντες πρέπει να μεταφορτώσουν το δικό τους βίντεο ατομικά για κάθε άλλο συμμετέχοντα, κάτι που πιθανότατα θα προκαλέσει προβλήματα σύνδεσης και υψηλό φόρτο στις συμμετέχουσες συσκευές.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Συνιστάται ιδιαίτερα η ρύθμιση μιας κατανεμημένης cache όταν χρησιμοποιείτε το Nextcloud Talk με ένα backend υψηλής απόδοσης.",
    "Add High-performance backend server" : "Προσθήκη διακομιστή backend υψηλής απόδοσης",
    "Warn about connectivity issues in calls with more than 2 participants" : "Προειδοποίηση για προβλήματα σύνδεσης σε κλήσεις με περισσότερους από 2 συμμετέχοντες",
    "STUN server URL" : "URL διακομιστή STUN",
    "The server address is invalid" : "Η διεύθυνση του διακομιστή είναι μη έγκυρη",
    "STUN settings saved" : "Οι ρυθμίσεις STUN αποθηκεύτηκαν",
    "STUN servers" : "Διακομιστές STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Ένας διακομιστής STUN χρησιμοποιείται για τον καθορισμό της δημόσιας διεύθυνσης IP των συμμετεχόντων πίσω από ένα δρομολογητή.",
    "Add a new STUN server" : "Προσθήκη νέου διακομιστή STUN",
    "{schema} scheme must be used with a domain" : "Το σχήμα {schema} πρέπει να χρησιμοποιείται με έναν domain",
    "{option1} and {option2}" : "{option1} και {option2}",
    "{option} only" : "μόνο {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "ΟΚ: Επιτυχής ανταλλαγή πληροφοριών ICE από τον διακομιστή TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Σφάλμα: Μη επιτυχής ανταλλαγή πληροφοριών ICE από τον διακομιστή TURN",
    "Testing whether the TURN server returns ICE candidates" : "Δοκιμή ασχέτως εάν ο διακομιστής TURN παρέχει πληροφορίες ICE",
    "TURN server schemes" : "Σχήματα διακομιστή TURN",
    "TURN server URL" : "URL διακομιστή TURN",
    "TURN server secret" : "Μυστικό του διακομιστή TURN",
    "TURN server protocols" : "Πρωτόκολλα διακομιστή TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Ένας διακομιστής TURN χρησιμοποιείται για να διαμεσολαβεί την κίνηση από συμμετέχοντες πίσω από ένα firewall. Εάν μεμονωμένοι συμμετέχοντες δεν μπορούν να συνδεθούν με άλλους, πιθανότατα απαιτείται διακομιστής TURN. Δείτε {linkstart}αυτή την τεκμηρίωση{linkend} για οδηγίες ρύθμισης.",
    "TURN settings saved" : "Οι ρυθμίσεις TURN αποθηκεύτηκαν",
    "TURN servers" : "Διακομιστές TURN",
    "Add a new TURN server" : "Προσθήκη νέου διακομιστή TURN",
    "Failed" : "Απέτυχε",
    "OK" : "OK",
    "Checking …" : "Έλεγχος …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Απέτυχε: Το WebAssembly είναι απενεργοποιημένο ή δεν υποστηρίζεται σε αυτό το πρόγραμμα περιήγησης. Παρακαλώ ενεργοποιήστε το WebAssembly ή χρησιμοποιήστε ένα πρόγραμμα περιήγησης με υποστήριξη για να κάνετε τον έλεγχο.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Απέτυχε: Τα αρχεία \".wasm\" και \".tflite\" δεν επέστρεψαν σωστά από τον διακομιστή ιστού. Παρακαλώ ελέγξτε την ενότητα \"Απαιτήσεις συστήματος\" στην τεκμηρίωση Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: Τα αρχεία \".wasm\" και \".tflite\" επέστρεψαν σωστά από τον διακομιστή ιστού.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Φαίνεται ότι η διαμόρφωση PHP και Apache δεν είναι συμβατή. Παρακαλώ σημειώστε ότι το PHP μπορεί να χρησιμοποιηθεί μόνο με την ενότητα MPM_PREFORK και το PHP-FPM μπορεί να χρησιμοποιηθεί μόνο με την ενότητα MPM_EVENT.",
    "Web server setup checks" : "Έλεγχοι ρύθμισης διακομιστή ιστού",
    "Files required for virtual background can be loaded" : "Τα αρχεία που απαιτούνται για εικονικό φόντο μπορούν να φορτωθούν",
    "Federated user" : "Federated χρήστης",
    "Assign participants to rooms" : "Ανάθεση συμμετεχόντων σε δωμάτια",
    "Configure breakout rooms" : "Διαμόρφωση δωματίων ομάδων",
    "Number of breakout rooms" : "Αριθμός δωματίων ομάδων",
    "You can create from 1 to 20 breakout rooms." : "Μπορείτε να δημιουργήσετε από 1 έως 20 δωμάτια ομάδων.",
    "Assignment method" : "Μέθοδος ανάθεσης",
    "Automatically assign participants" : "Αυτόματη ανάθεση συμμετεχόντων",
    "Manually assign participants" : "Χειροκίνητη ανάθεση συμμετεχόντων",
    "Allow participants to choose" : "Να επιτρέπεται στους συμμετέχοντες να επιλέγουν",
    "Create rooms" : "Δημιουργία δωματίων",
    "Confirm" : "Επιβεβαίωση",
    "Create breakout rooms" : "Δημιουργία δωματίων ομάδων",
    "Reset" : "Επαναφορά",
    "Delete breakout rooms" : "Διαγραφή δωματίων διάσπασης",
    "Room {roomNumber}" : "Δωμάτιο {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Τα τρέχοντα δωμάτια διάσπασης και οι ρυθμίσεις θα χαθούν",
    "Cancel" : "Ακύρωση",
    "Unassigned participants" : "Μη αντιστοιχισμένοι συμμετέχοντες",
    "Back" : "Πίσω",
    "Assign" : "Αντιστοίχιση",
    "Add participant \"{user}\"" : "Προσθήκη συμμετέχοντος \"{user}\"",
    "Now" : "Τώρα",
    "Invalid calendar selected" : "Επιλέχθηκε μη έγκυρο ημερολόγιο",
    "Invalid start time selected" : "Επιλέχθηκε μη έγκυρη ώρα έναρξης",
    "Invalid end time selected" : "Επιλέχθηκε μη έγκυρη ώρα λήξης",
    "Unknown error occurred" : "Παρουσιάστηκε άγνωστο σφάλμα",
    "Sending no invitations" : "Δεν αποστέλλονται προσκλήσεις",
    "{participant0} will receive an invitation" : "Ο/Η {participant0} θα λάβει πρόσκληση",
    "{participant0} and {participant1} will receive invitations" : "Ο/Η {participant0} και ο/η {participant1} θα λάβουν προσκλήσεις",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["Ο/Η {participant0}, ο/η {participant1} και %n ακόμα θα λάβουν προσκλήσεις","Ο/Η {participant0}, ο/η {participant1} και %n ακόμα θα λάβουν προσκλήσεις"],
    "Invite {user}" : "Πρόσκληση {user}",
    "Invite all users and emails in this conversation" : "Πρόσκληση όλων των χρηστών και email σε αυτή τη συνομιλία",
    "Meeting created" : "Η συνάντηση δημιουργήθηκε",
    "Upcoming meetings" : "Προσεχείς συναντήσεις",
    "Loading …" : "Φόρτωση…",
    "No upcoming meetings" : "Δεν υπάρχουν προσεχείς συναντήσεις",
    "Schedule a meeting" : "Προγραμματισμός συνάντησης",
    "Meeting title" : "Τίτλος συνάντησης",
    "From" : "Από",
    "To" : "Έως",
    "Calendar" : "Ημερολόγιο",
    "Attendees" : "Συμμετέχοντες",
    "No other participants to send invitations to." : "Δεν υπάρχουν άλλοι συμμετέχοντες για αποστολή προσκλήσεων.",
    "Add attendees" : "Προσθήκη συμμετεχόντων",
    "Save" : "Αποθήκευση",
    "Search participants" : "Αναζήτηση συμμετεχόντων",
    "No results" : "Κανένα αποτέλεσμα",
    "Done" : "Ολοκληρώθηκε",
    "Disable live transcription" : "Απενεργοποίηση ζωντανής μεταγραφής",
    "Raise hand" : "Σήκωμα χεριού",
    "Raise hand (R)" : "Σήκωμα χεριού (R)",
    "Lower hand" : "Κατέβασμα χεριού",
    "Lower hand (R)" : "Κατέβασμα χεριού (R)",
    "Exit full screen (F)" : "Έξοδος από πλήρη οθόνη (F)",
    "Full screen (F)" : "Πλήρης οθόνη (F)",
    "Speaker view" : "Προβολή ομιλητή",
    "Grid view" : "Προβολή πλέγματος",
    "Error when trying to load the available live transcription languages" : "Σφάλμα κατά τη φόρτωση των διαθέσιμων γλωσσών ζωντανής μεταγραφής",
    "Failed to enable live transcription" : "Αποτυχία ενεργοποίησης ζωντανής μεταγραφής",
    "Recording consent is required" : "Απαιτείται συγκατάθεση για εγγραφή",
    "This conversation is read-only" : "Αυτή η συνομιλία είναι μόνο για ανάγνωση",
    "Conversation not found or not joined" : "Η συνομιλία δεν βρέθηκε ή δεν έχετε συμμετάσχει",
    "Lobby is still active and you're not a moderator" : "Η αίθουσα αναμπνής είναι ακόμα ενεργό και δεν είστε συντονιστής",
    "Connection failed" : "Η σύνδεση απέτυχε",
    "Reload" : "Επαναφόρτωση",
    "{nickName} raised their hand." : "Ο {nickName} σήκωσε το χέρι του.",
    "A participant raised their hand." : "Ένας συμμετέχων σήκωσε το χέρι του.",
    "Collapse stripe" : "Σύμπτυξη λωρίδας",
    "Expand stripe" : "Ανάπτυξη λωρίδας",
    "Previous page of videos" : "Προηγούμενη σελίδα βίντεο",
    "Next page of videos" : "Επόμενη σελίδα βίντεο",
    "Connecting …" : "Σύνδεση ...",
    "Calling …" : "Κλήση σε εξέλιξη …",
    "Waiting for {user} to join the call" : "Αναμονή για είσοδο του/της {user} στην κλήση",
    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση …",
    "You can invite others in the participant tab of the sidebar" : "Μπορείτε να προσκαλέσετε άλλους από την καρτέλα συμμετεχόντων της πλευρικής μπάρας",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Μπορείτε να προσκαλέσετε άλλους από την καρτέλα συμμετεχόντων της πλευρικής μπάρας ή να κοινοποιήσετε αυτόν τον σύνδεσμο για να προσκαλέσετε άλλους!",
    "Share this link to invite others!" : "Κοινοποιήστε αυτόν τον σύνδεσμο για να προσκαλέσετε άλλους!",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "You are not allowed to enable audio" : "Δεν επιτρέπεται η ενεργοποίηση του ήχου",
    "No audio. Click to select device" : "Χωρίς ήχο. Κάντε κλικ για επιλογή συσκευής",
    "Mute audio" : "Σίγαση ήχου",
    "Mute audio (M)" : "Σίγαση ήχου (M)",
    "Unmute audio" : "Ενεργοποίηση ήχου",
    "Unmute audio (M)" : "Ενεργοποίηση ήχου (M)",
    "None" : "Κανένα",
    "Select a microphone" : "Επιλογή μικροφώνου",
    "Select a speaker" : "Επιλογή ηχείου",
    "Check devices" : "Έλεγχος συσκευών",
    "Access to camera was denied" : "Δεν επιτρέπεται η πρόσβαση στην κάμερα",
    "Error while accessing camera: It is likely in use by another program" : "Σφάλμα κατά την πρόσβαση στην κάμερα: Είναι πιθανό να χρησιμοποιείται από άλλο πρόγραμμα",
    "Error while accessing camera" : "Σφάλμα κατά την πρόσβαση στην κάμερα",
    "You have been muted by a moderator" : "Έχετε σιγαστεί από συντονιστή",
    "Hide presenter video" : "Απόκρυψη βίντεο παρουσιαστή",
    "You are not allowed to enable video" : "Δεν επιτρέπεται η ενεργοποίηση του βίντεο",
    "No video. Click to select device" : "Χωρίς βίντεο. Κάντε κλικ για επιλογή συσκευής",
    "Disable video" : "Απενεργοποίηση βίντεο",
    "Disable video (V)" : "Απενεργοποίηση βίντεο (V)",
    "Enable video" : "Ενεργοποίηση βίντεο",
    "Enable video (V)" : "Ενεργοποίηση βίντεο (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Ενεργοποίηση βίντεο - Η σύνδεσή σας θα διακοπεί σύντομα κατά την ενεργοποίηση του βίντεο για πρώτη φορά",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Ενεργοποίηση βίντεο (V) - Η σύνδεσή σας θα διακοπεί σύντομα κατά την ενεργοποίηση του βίντεο για πρώτη φορά",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Ενεργοποίηση βίντεο. Η σύνδεσή σας θα διακοπεί σύντομα κατά την ενεργοποίηση του βίντεο για πρώτη φορά",
    "Select a video device" : "Επιλογή συσκευής βίντεο",
    "Show presenter" : "Εμφάνιση παρουσιαστή",
    "You" : "Εσείς",
    "Mute" : "Σίγαση",
    "Muted" : "Σιγασμένο",
    "Show screen" : "Εμφάνιση οθόνης",
    "Stop following" : "Διακοπή ακολούθησης",
    "Connection could not be established …" : "Δεν ήταν δυνατή η δημιουργία σύνδεσης …",
    "Connection was lost and could not be re-established …" : "Η σύνδεση χάθηκε και δεν ήταν δυνατή η επανασύνδεση …",
    "Connection could not be established. Trying again …" : "Δεν ήταν δυνατή η δημιουργία σύνδεσης. Νέα προσπάθεια …",
    "Connection lost. Trying to reconnect …" : "Χαμένη σύνδεση. Προσπάθεια επανασύνδεσης …",
    "Connection problems …" : "Προβλήματα σύνδεσης …",
    "Collapse" : "Σύμπτυξη",
    "Expand" : "Επεκτείνω",
    "You need to be logged in to upload files" : "Πρέπει είστε σε σύνδεση για ανέβασμα αρχείων",
    "Drop your files to upload" : "Αποθέστε τα αρχεία σας για ανέβασμα",
    "Conversation messages" : "Μηνύματα συνομιλίας",
    "Scroll to bottom" : "Μετακινηθείτε προς τα κάτω",
    "Post message" : "Δημοσίευση μηνύματος",
    "Federated conversation" : "Ομοσπονδιακή συνομιλία",
    "Public conversation" : "Δημόσια συνομιλία",
    "Favorite" : "Προσθήκη στα αγαπημένα",
    "Banned users" : "Αποκλεισμένοι χρήστες",
    "Manage the list of banned users in this conversation." : "Διαχείριση της λίστας αποκλεισμένων χρηστών σε αυτή τη συνομιλία.",
    "Manage bans" : "Διαχείριση αποκλεισμών",
    "No banned users" : "Δεν υπάρχουν αποκλεισμένοι χρήστες",
    "Banned by:" : "Αποκλείστηκε από:",
    "Date:" : "Ημερομηνία:",
    "Note:" : "Σημείωση:",
    "Hide details" : "Απόκρυψη λεπτομερειών",
    "Show details" : "Εμφάνιση λεπτομερειών",
    "Unban" : "Απο-αποκλεισμός",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Μπορείτε να αλλάξετε τον τίτλο και την περιγραφή στο {linkstart}Ημερολόγιο ↗{linkend}.",
    "Error while updating conversation name" : "Σφάλμα κατά την ενημέρωση του ονόματος συνομιλίας",
    "Error while updating conversation description" : "Σφάλμα κατά την ενημέρωση της περιγραφής συνομιλίας",
    "Enter a name for this conversation" : "Εισάγετε ένα όνομα για αυτή τη συνομιλία",
    "Edit conversation name" : "Επεξεργασία ονόματος συνομιλίας",
    "Edit conversation description" : "Επεξεργασία περιγραφής συνομιλίας",
    "Enter a description for this conversation" : "Πληκτρολογήστε μια περιγραφή για αυτήν τη συνομιλία",
    "Picture" : "Εικόνα",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Τα ακόλουθα bots μπορούν να ενεργοποιηθούν σε αυτή τη συνομιλία. Επικοινωνήστε με τον διαχειριστή σας για να εγκαταστήσετε περισσότερα bots σε αυτόν τον server.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Δεν υπάρχουν εγκατεστημένα bots σε αυτόν τον server. Επικοινωνήστε με τον διαχειριστή σας για να εγκαταστήσετε bots σε αυτόν τον server.",
    "Disable" : "Απενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Breakout rooms" : "Δωμάτια διάσπασης",
    "Manage breakout rooms" : "Διαχείριση δωματίων διάσπασης",
    "Set up breakout rooms for this conversation" : "Ρύθμιση δωματίων διάσπασης για αυτή τη συνομιλία",
    "Please select a valid PNG or JPG file" : "Παρακαλώ επιλέξτε ένα έγκυρο αρχείο PNG ή JPG",
    "Choose your conversation picture" : "Επιλέξτε την εικόνα συνομιλίας σας",
    "Choose" : "Επιλογή",
    "Error setting conversation picture" : "Σφάλμα κατά την ρύθμιση της εικόνας συνομιλίας",
    "Could not set the conversation picture: {error}" : "Δεν ήταν δυνατή η ρύθμιση της εικόνας συνομιλίας: {error}",
    "Error cropping conversation picture" : "Σφάλμα κατά την περικοπή της εικόνας συνομιλίας",
    "Error removing conversation picture" : "Σφάλμα κατά την αφαίρεση της εικόνας συνομιλίας",
    "Set emoji as conversation picture" : "Ορισμός emoji ως εικόνας συνομιλίας",
    "Set background color for conversation picture" : "Ορισμός χρώματος φόντου για εικόνα συνομιλίας",
    "Upload conversation picture" : "Μεταφόρτωση εικόνας συνομιλίας",
    "Choose conversation picture from files" : "Επιλογή εικόνας συνομιλίας από αρχεία",
    "Remove conversation picture" : "Αφαίρεση εικόνας συνομιλίας",
    "The file must be a PNG or JPG" : "Το αρχείο πρέπει να είναι τύπου PNG ή JPG",
    "Set picture" : "Ορισμός εικόνας",
    "Default permissions modified for {conversationName}" : "Τα προεπιλεγμένα δικαιώματα τροποποιήθηκαν για {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Δεν ήταν δυνατή η τροποποίηση των προεπιλεγμένων δικαιωμάτων για {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Επεξεργαστείτε τα προεπιλεγμένα δικαιώματα για τους συμμετέχοντες σε αυτή τη συνομιλία. Αυτές οι ρυθμίσεις δεν επηρεάζουν τους συντονιστές.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Κάθε φορά που τροποποιούνται τα δικαιώματα σε αυτή την ενότητα, τα προσαρμοσμένα δικαιώματα που είχαν ανατεθεί προηγουμένως σε μεμονωμένους συμμετέχοντες θα χαθούν.",
    "All permissions" : "Όλα τα δικαιώματα",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Οι συμμετέχοντες έχουν δικαιώματα για έναρξη κλήσης, συμμετοχή σε κλήση, ενεργοποίηση ήχου και βίντεο και κοινή χρήση οθόνης.",
    "Restricted" : "Περιορισμένο",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Οι συμμετέχοντες μπορούν να συμμετέχουν σε κλήσεις, αλλά δεν μπορούν να ενεργοποιήσουν τον ήχο ή το βίντεο ούτε να μοιραστούν την οθόνη έως ότου ένας συντονιστής τους εκχωρήσει αυτά τα δικαιώματα.",
    "Advanced permissions" : "Προσαρμοσμένα δικαιώματα",
    "Edit permissions" : "Επεξεργασία δικαιωμάτων",
    "Conversation settings" : "Ρυθμίσεις συνομιλίας",
    "Basic Info" : "Βασικές Πληροφορίες",
    "Personal" : "Προσωπικός",
    "Moderation" : "Συντονισμός",
    "Setup overview" : "Επισκόπηση ρύθμισης",
    "Live transcription" : "Ζωντανή μεταγραφή",
    "Enable live transcription" : "Ενεργοποίηση ζωντανής μεταγραφής",
    "Breakout Rooms" : "Δωμάτια Διάσπασης",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Επικίνδυνη ζώνη",
    "Archive conversation" : "Αρχειοθέτηση συνομιλίας",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Οι αρχειοθετημένες συνομιλίες είναι κρυφές από την λίστα συνομιλιών από προεπιλογή. Ωστόσο, θα εμφανίζονται όταν αναζητάτε το όνομα της συνομιλίας ή προσπελάσετε μια λίστα αρχειοθετημένων συνομιλιών.",
    "Do you really want to leave \"{displayName}\"?" : "Θέλετε πραγματικά να εγκαταλείψετε τη συνομιλία \"{displayName}\";",
    "You can archive this conversation instead." : "Μπορείτε να αρχειοθετήσετε αυτή τη συνομιλία αντί αυτού.",
    "Leave conversation" : "Εγκατάλειψη συνομιλίας",
    "You need to promote a new moderator before you can leave the conversation" : "Πρέπει να προβιβάσετε έναν νέο συντονιστή πριν μπορέσετε να εγκαταλείψετε τη συνομιλία",
    "Delete conversation" : "Διαγραφή συνομιλίας",
    "Do you really want to delete \"{displayName}\"?" : "Θέλετε σίγουρα να διαγράψετε το \"{displayName}\";",
    "Error while deleting conversation" : "Σφάλμα κατά τη διαγραφή της συνομιλίας",
    "Delete all chat messages" : "Διαγραφή όλων των μηνυμάτων συνομιλίας",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Θέλετε πραγματικά να διαγράψετε όλα τα μηνύματα στο \"{displayName}\";",
    "Error while clearing chat history" : "Σφάλμα κατά την εκκαθάριση του ιστορικού συνομιλιών",
    "Be careful, these actions cannot be undone." : "Προσέξτε, αυτές οι ενέργειες δεν μπορούν να αναιρεθούν.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Μόλις εγκαταλείψετε μια συνομιλία, για να επανενταχθείτε σε μια κλειστή συνομιλία, απαιτείται πρόσκληση. Μια ανοιχτή συνομιλία μπορεί να επανενταχθεί ανά πάσα στιγμή.",
    "Permanently delete this conversation." : "Οριστική διαγραφή αυτής της συνομιλίας.",
    "Delete chat messages" : "Διαγραφή μηνυμάτων συνομιλίας",
    "Permanently delete all the messages in this conversation." : "Οριστική διαγραφή όλων των μηνυμάτων σε αυτήν τη συνομιλία.",
    "_%n hour_::_%n hours_" : ["%n ώρα","%n ώρες"],
    "_%n day_::_%n days_" : ["%n ημέρα","%n ημέρες"],
    "_%n week_::_%n weeks_" : ["%n εβδομάδα","%n εβδομάδες"],
    "Custom expiration time" : "Προσαρμοσμένος χρόνος λήξης",
    "Message expiration disabled" : "Η λήξη μηνυμάτων απενεργοποιήθηκε",
    "Message expiration set: {duration}" : "Ορίστηκε λήξη μηνυμάτων: {duration}",
    "Error when trying to set message expiration" : "Σφάλμα κατά την προσπάθεια ορισμού λήξης μηνυμάτων",
    "Message expiration" : "Λήξη μηνυμάτων",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Τα μηνύματα συνομιλίας μπορούν να λήξουν μετά από συγκεκριμένο χρόνο. Σημείωση: Τα αρχεία που κοινοποιούνται στη συνομιλία δεν θα διαγραφούν για τον κάτοχο, αλλά δεν θα κοινοποιούνται πλέον στη συνομιλία.",
    "Set message expiration" : "Ορισμός λήξης μηνυμάτων",
    "Current message expiration" : "Τρέχουσα λήξη μηνυμάτων",
    "Password copied to clipboard" : "Το συνθηματικό αντιγράφηκε στο πρόχειρο",
    "Password could not be copied" : "Το συνθηματικό δεν μπορούσε να αντιγραφεί",
    "Guest access" : "Πρόσβαση επισκεπτών",
    "Breakout rooms are not allowed in public conversations." : "Τα δωμάτια διάσπασης δεν επιτρέπονται σε δημόσιες συνομιλίες.",
    "Allow guests to join this conversation via link" : "Να επιτρέπεται σε επισκέπτες να συμμετέχουν σε αυτή τη συνομιλία μέσω συνδέσμου",
    "Password protection" : "Προστασία συνθηματικού",
    "This conversation is password-protected. Guests need password to join" : "Αυτή η συνομιλία προστατεύεται με συνθηματικό. Οι επισκέπτες χρειάζονται συνθηματικό για να συμμετάσχουν",
    "Password protection is needed for public conversations" : "Απαιτείται προστασία συνθηματικού για δημόσιες συνομιλίες",
    "Set a password" : "Ορισμός συνθηματικού",
    "Change password" : "Αλλαγή συνθηματικού",
    "Enter new password" : "Εισαγωγή νέου συνθηματικού",
    "Save password" : "Αποθήκευση συνθηματικού",
    "Copy password" : "Αντιγραφή συνθηματικού",
    "Guests are allowed to join this conversation via link" : "Επιτρέπεται σε επισκέπτες να συμμετέχουν σε αυτή τη συνομιλία μέσω συνδέσμου",
    "Guests are not allowed to join this conversation" : "Δεν επιτρέπεται σε επισκέπτες να συμμετέχουν σε αυτή τη συνομιλία",
    "Resend invitations" : "Επαναποστολή προσκλήσεων",
    "This conversation is open to both registered users and users created with the Guests app" : "Αυτή η συνομιλία είναι ανοιχτή τόσο σε εγγεγραμμένους χρήστες όσο και σε χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "This conversation is open to registered users" : "Αυτή η συνομιλία είναι ανοιχτή σε εγγεγραμμένους χρήστες",
    "This conversation is limited to the current participants" : "Αυτή η συνομιλία περιορίζεται στους τρέχοντες συμμετέχοντες",
    "You opened the conversation to both registered users and users created with the Guests app" : "Ανοίξατε τη συνομιλία τόσο σε εγγεγραμμένους χρήστες όσο και σε χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "Error occurred when opening or limiting the conversation" : "Συνέβη σφάλμα κατά το άνοιγμα ή τον περιορισμό της συνομιλίας",
    "Open conversation to registered users, showing it in search results" : "Άνοιγμα συνομιλίας σε εγγεγραμμένους χρήστες, εμφάνισή της στα αποτελέσματα αναζήτησης",
    "Also open to users created with the Guests app" : "Επίσης ανοιχτή σε χρήστες που δημιουργήθηκαν με την εφαρμογή Επισκεπτών",
    "Open conversation" : "Άνοιγμα συνομιλίας",
    "Set language spoken in calls" : "Ορισμός γλώσσας που ομιλείται στις κλήσεις",
    "Languages could not be loaded" : "Οι γλώσσες δεν μπόρεσαν να φορτωθούν",
    "Loading languages …" : "Φόρτωση γλωσσών …",
    "Invalid language" : "Μη έγκυρη γλώσσα",
    "Default language (English)" : "Προεπιλεγμένη γλώσσα (Αγγλικά)",
    "Default live transcription language set" : "Ορίστηκε προεπιλεγμένη γλώσσα ζωντανής μεταγραφής",
    "Live transcription language set: {languageName}" : "Ορίστηκε γλώσσα ζωντανής μεταγραφής: {languageName}",
    "Error when trying to set live transcription language" : "Σφάλμα κατά την προσπάθεια ορισμού γλώσσας ζωντανής μεταγραφής",
    "Start time: {date}" : "Ώρα έναρξης: {date}",
    "Start time has been updated" : "Η ώρα έναρξης ενημερώθηκε",
    "Error occurred while updating start time" : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση της ώρας έναρξης",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Η ενεργοποίηση της αίθουσας αναμονής θα απομακρύνει τους μη συντονιστές από την τρέχουσα κλήση.",
    "Enable lobby, restricting the conversation to moderators" : "Ενεργοποίηση αιθουσας αναμονής, περιορίζοντας τη συνομιλία σε συντονιστές",
    "Meeting start time" : "Ώρα έναρξης της συνάντησης",
    "Start time (optional)" : "Ώρα έναρξης (προαιρετικό)",
    "Import email participants" : "Εισαγωγή συμμετεχόντων μέσω email",
    "You can import a list of email participants from a CSV file." : "Μπορείτε να εισάγετε μια λίστα συμμετεχόντων μέσω email από ένα αρχείο CSV.",
    "Poll drafts" : "Προσχέδια δημοσκοτήσεων",
    "Browse poll drafts" : "Περιήγηση στα προσχέδια δημοσκοτήσεων",
    "Error occurred when locking the conversation" : "Παρουσιάστηκε σφάλμα κατά το κλείδωμα της συνομιλίας",
    "Error occurred when unlocking the conversation" : "Παρουσιάστηκε σφάλμα κατά το ξεκλείδωμα της συνομιλίας",
    "Lock conversation" : "Κλειδώστε τη συνομιλία",
    "This will also terminate the ongoing call." : "Αυτό θα τερματίσει επίσης την τρέχουσα κλήση.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Κλειδώστε τη συνομιλία για να αποτρέψετε την ανάρτηση μηνυμάτων ή την έναρξη κλήσεων",
    "Edit" : "Επεξεργασία",
    "More information" : "Περισσότερες πληροφορίες",
    "Delete" : "Διαγραφή",
    "Add new bridged channel to current conversation" : "Προσθέστε νέο γεφυρωμένο κανάλι στην τρέχουσα συνομιλία",
    "unknown state" : "άγνωστη κατάσταση",
    "running" : "εκτελείται",
    "not running, check Matterbridge log" : "δεν εκτελείται, ελέγξτε το αρχείο καταγραφής Matterbridge",
    "not running" : "δεν εκτελείται",
    "Bridge saved" : "Η σύνδεση αποθηκεύτηκε",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Μπορείτε να συνδέσετε κανάλια από διάφορα άλλα συστήματα άμεσων μηνυμάτων με το Matterbridge.",
    "More info on Matterbridge" : "Περισσότερες πληροφορίες για το Matterbridge",
    "Messaging systems" : "Συστήματα ανταλλαγής μηνυμάτων",
    "Enable bridge" : "Ενεργοποίηση γέφυρας",
    "Show Matterbridge log" : "Εμφάνιση αρχείου καταγραφής Matterbridge",
    "Log content" : "Περιεχόμενα αρχείου καταγραφής",
    "Only moderators are allowed to mention @all" : "Μόνο οι συντονιστές επιτρέπεται να αναφέρονται σε @all",
    "All participants are allowed to mention @all" : "Όλοι οι συμμετέχοντες επιτρέπεται να αναφέρονται σε @all",
    "Participants are now allowed to mention @all." : "Οι συμμετέχοντες επιτρέπεται πλέον να αναφέρονται σε @all.",
    "Mentioning @all has been limited to moderators." : "Η αναφορά σε @all περιορίστηκε στους συντονιστές.",
    "Allow participants to mention @all" : "Να επιτρέπεται στους συμμετέχοντες η αναφορά σε @all",
    "Mention permissions" : "Δικαιώματα αναφοράς",
    "Notifications" : "Ειδοποιήσεις",
    "Notify about calls in this conversation" : "Να ειδοποιούμαι για κλήσεις σε αυτήν τη συνομιλία",
    "Important conversation" : "Σημαντική συνομιλία",
    "\"Do not disturb\" user status is ignored for important conversations" : "Η κατάσταση χρήστη \"Μην ενοχλείτε\" αγνοείται για σημαντικές συνομιλίες",
    "Sensitive conversation" : "Ευαίσθητη συνομιλία",
    "Message preview will be disabled in conversation list and notifications" : "Η προεπισκόπηση μηνυμάτων θα απενεργοποιηθεί στη λίστα συνομιλιών και στις ειδοποιήσεις",
    "Recording consent is required for calls in this conversation" : "Απαιτείται συγκατάθεση εγγραφής για τις κλήσεις σε αυτή τη συνομιλία",
    "Recording consent is not required for calls in this conversation" : "Δεν απαιτείται συγκατάθεση εγγραφής για τις κλήσεις σε αυτή τη συνομιλία",
    "Recording consent requirement was updated" : "Η απαίτηση συγκατάθεσης εγγραφής ενημερώθηκε",
    "Error occurred while updating recording consent" : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση της συγκατάθεσης εγγραφής",
    "Recording Consent" : "Συγκατάθεση Εγγραφής",
    "Recording consent cannot be changed once a call or breakout session has started." : "Η συγκατάθεση εγγραφής δεν μπορεί να αλλάξει μόλις ξεκινήσει μια κλήση ή συνεδρία διάσπασης.",
    "Require recording consent before joining call in this conversation" : "Απαιτείται συγκατάθεση εγγραφής πριν από τη συμμετοχή σε κλήση σε αυτή τη συνομιλία",
    "Recording consent is required for all calls" : "Η συγκατάθεση εγγραφής απαιτείται για όλες τις κλήσεις",
    "SIP dial-in is now possible without PIN requirement" : "Το SIP dial-in είναι πλέον δυνατό χωρίς απαίτηση PIN",
    "SIP dial-in is now enabled" : "Το SIP dial-in είναι πλέον ενεργοποιημένο",
    "SIP dial-in is now disabled" : "Το SIP dial-in είναι πλέον απενεργοποιημένο",
    "Error occurred when enabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την ενεργοποίηση του SIP dial-in",
    "Error occurred when disabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την απενεργοποίηση του SIP dial-in",
    "Phone and SIP dial-in" : "Τηλεφωνική και SIP σύνδεση",
    "Enable phone and SIP dial-in" : "Ενεργοποίηση τηλεφωνικής και SIP σύνδεσης",
    "Allow to dial-in without a PIN" : "Να επιτρέπεται η σύνδεση χωρίς PIN",
    "Ongoing" : "Σε εξέλιξη",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n άτομο δέχτηκε","%n άτομα δέχτηκαν"],
    "_%n person declined_::_%n people declined_" : ["%n άτομο απέρριψε","%n άτομα απέρριψαν"],
    "_and %n other attachment_::_and %n other attachments_" : ["και %n άλλο συνημμένο","και %n άλλα συνημμένα"],
    "With {displayName}" : "Με {displayName}",
    "In {conversation}" : "Στη συνομιλία {conversation}",
    "View attachment" : "Προβολή συνημμένου",
    "Join" : "Συμμετοχή",
    "View conversation" : "Προβολή συνομιλίας",
    "View event on Calendar" : "Προβολή συμβάντος στο Ημερολόγιο",
    "Error while creating the conversation" : "Σφάλμα κατά τη δημιουργία συνομιλίας",
    "Hello, {displayName}" : "Γεια σας, {displayName}",
    "Start meeting now" : "Έναρξη συνεδρίας τώρα",
    "Give your meeting a title" : "Δώστε έναν τίτλο στη συνεδρία σας",
    "Create and copy link" : "Δημιουργία και αντιγραφή συνδέσμου",
    "Create a new conversation" : "Δημιουργία νέας συνομιλίας",
    "Join open conversations" : "Συμμετοχή σε ανοικτές συνομιλίες",
    "Call a phone number" : "Κλήση σε αριθμό τηλεφώνου",
    "Scroll backward" : "Κύλιση προς τα πίσω",
    "Scroll forward" : "Κύλιση προς τα εμπρός",
    "Schedule meetings" : "Προγραμματισμός συναντήσεων",
    "You don't have any upcoming meetings" : "Δεν έχετε επερχόμενες συναντήσεις",
    "Open calendar" : "Άνοιγμα ημερολογίου",
    "Unread mentions" : "Αδιάβαστες αναφορές",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Τα μηνύματα όπου αναφερθήκατε θα εμφανίζονται εδώ. Μπορείτε να αναφέρετε άτομα πληκτρολογώντας @ ακολουθούμενο από το όνομά τους",
    "Upcoming reminders" : "Επερχόμενες υπενθυμίσεις",
    "Message reminders" : "Υπενθυμίσεις μηνυμάτων",
    "Set a reminder on a message to be notified" : "Ορίστε μια υπενθύμιση σε ένα μήνυμα για να ειδοποιηθείτε",
    "Start a group conversation" : "Έναρξη ομαδικής συνομιλίας",
    "Create conversation" : "Δημιουργία συνομιλίας",
    "Enter your name" : "Προσθέστε το όνομά σας",
    "Submit name and join" : "Υποβολή ονόματος και συμμετοχή",
    "Do you already have an account?" : "Έχετε ήδη λογαριασμό;",
    "Log in" : "Είσοδος",
    "Error while verifying uploaded file" : "Σφάλμα κατά την επαλήθευση του ανεβασμένου αρχείου",
    "Uploaded file is verified" : "Το ανεβασμένο αρχείο επαληθεύτηκε",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Η μορφή περιεχομένου είναι τιμές διαχωρισμένες με κόμμα (CSV):<br/>- Απαιτείται γραμμή κεφαλίδας και πρέπει να ταιριάζει με <samp>\"name\",\"email\"</samp> ή μόνο <samp>\"email\"</samp><br/>- Μία εγγραφή ανά γραμμή (π.χ. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Οι συμμετέχοντες προστέθηκαν με επιτυχία",
    "Error while adding participants" : "Σφάλμα κατά την προσθήκη συμμετεχόντων",
    "Import a file" : "Εισαγωγή αρχείου",
    "Browse" : "Περιήγηση",
    "Verifying uploaded file …" : "Επαλήθευση ανεβασμένου αρχείου …",
    "This might take a moment" : "Αυτό μπορεί να πάρει λίγο χρόνο",
    "Send invitations" : "Αποστολή προσκλήσεων",
    "_%n invalid email_::_%n invalid emails_" : ["%n μη έγκυρο email","%n μη έγκυρα emails"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n email έχει ήδη εισαχθεί ή είναι διπλότυπο","%n emails έχουν ήδη εισαχθεί ή είναι διπλότυπα"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n πρόσκληση μπορεί να αποσταλεί","%n προσκλήσεις μπορούν να αποσταλούν"],
    "An error occurred while calling a phone number" : "Παρουσιάστηκε σφάλμα κατά την κλήση σε αριθμό τηλεφώνου",
    "Phone number could not be called: {error}" : "Ο αριθμός τηλεφώνου δεν μπορούσε να καλεστεί: {error}",
    "Phone number could not be called" : "Ο αριθμός τηλεφώνου δεν μπορούσε να καλεστεί",
    "Search participants or phone numbers" : "Αναζήτηση συμμετεχόντων ή αριθμών τηλεφώνου",
    "Creating the conversation …" : "Δημιουργία συνομιλίας …",
    "Mark as read" : "Σήμανση ως αναγνωσμένο",
    "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
    "Unarchive conversation" : "Απο-αρχειοθέτηση συνομιλίας",
    "Ignore \"Do not disturb\"" : "Αγνόηση \"Μην ενοχλείτε\"",
    "You need to promote a new moderator before you can leave the conversation." : "Πρέπει να προάγετε έναν νέο συντονιστή πριν μπορέσετε να αποχωρήσετε από τη συνομιλία.",
    "Conversation actions" : "Δράσεις συνομιλιών",
    "Notify about calls" : "Ειδοποίηση για κλήσεις",
    "Hide message text" : "Απόκρυψη κειμένου μηνύματος",
    "Pending invitations" : "Εκκρεμείς προσκλήσεις",
    "From {user} at {remoteServer}" : "Από {user} στον {remoteServer}",
    "Decline invitation" : "Απόρριψη πρόσκλησης",
    "Accept invitation" : "Αποδοχή πρόσκλησης",
    "No pending invitations" : "Δεν υπάρχουν εκκρεμείς προσκλήσεις",
    "Home" : "Αρχική",
    "Unread" : "Μη αναγνωσμένο",
    "Mentions" : "Αναφορές",
    "Meetings" : "Συναντήσεις",
    "Alphabetically" : "Αλφαβητικά",
    "No followed threads" : "Δεν υπάρχουν ακολουθούμενες συζητήσεις",
    "No matches found" : "Δεν βρέθηκαν αντιστοιχίες",
    "No conversations found" : "Δεν βρέθηκαν συνομιλίες",
    "You have no archived conversations." : "Δεν έχετε αρχειοθετημένες συνομιλίες.",
    "Subscribe to an existing thread or start your own." : "Εγγραφείτε σε μια υπάρχουσα συζήτηση ή ξεκινήστε τη δική σας.",
    "You have no unread mentions." : "Δεν έχετε αδιάβαστες αναφορές.",
    "You have no unread messages." : "Δεν έχετε αδιάβαστα μηνύματα.",
    "An error occurred while performing the search" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση",
    "Conversation list" : "Λίστα συνομιλιών",
    "Filter conversations by" : "Φιλτράρισμα συνομιλιών κατά",
    "Unread messages" : "Μη αναγνωσμένα μηνύματα",
    "Meeting conversations" : "Συνομιλίες συναντήσεων",
    "Clear filters" : "Εκκαθάριση φίλτρων",
    "New personal note" : "Νέα προσωπική σημείωση",
    "Back to conversations" : "Επιστροφή στις συνομιλίες",
    "Archived conversations" : "Αρχειοθετημένες συνομιλίες",
    "Threads" : "Συζητήσεις",
    "Clear filter" : "Εκκαθάριση φίλτρου",
    "Show more threads" : "Εμφάνιση περισσότερων συζητήσεων",
    "App settings" : "Ρυθμίσεις εφαρμογής",
    "Users" : "Χρήστες",
    "Groups" : "Ομάδες",
    "Teams" : "Ομάδες",
    "Federated users" : "Ομοσπονδιακοί χρήστες",
    "New private conversation" : "Νέα ιδιωτική συνομιλία",
    "Other sources" : "Άλλες πηγές",
    "Open conversations" : "Άνοιγμα συνομιλιών",
    "No search results" : "Κανένα αποτέλεσμα",
    "Users, groups and teams" : "Χρήστες, ομάδες και ομάδες",
    "Users and groups" : "Χρήστες και ομάδες",
    "Users and teams" : "Χρήστες και ομάδες",
    "Groups and teams" : "Ομάδες και ομάδες",
    "New group conversation" : "Νέα ομαδική συνομιλία",
    "The meeting will start soon" : "Η συνάντηση θα ξεκινήσει σύντομα",
    "This meeting is scheduled for {startTime}" : "Αυτή η συνάντηση είναι προγραμματισμένη για {startTime}",
    "You are currently waiting in the lobby" : "Βρίσκεστε στην αιθουα αναμονης",
    "Select microphone" : "Επιλογή μικροφώνου",
    "No microphone available" : "Δεν βρέθηκε μικρόφωνο",
    "Select speaker" : "Επιλογή ηχείου",
    "No speaker available" : "Δεν υπάρχει διαθέσιμο ηχείο",
    "Select camera" : "Επιλογή κάμερας",
    "No camera available" : "Δεν υπάρχει διαθέσιμη κάμερα",
    "Select a device" : "Επιλογή συσκευής",
    "Playing …" : "Αναπαραγωγή …",
    "Test speakers" : "Δοκιμή ηχείων",
    "Test" : "Δοκιμή",
    "Devices" : "Συσκευές",
    "Backgrounds" : "Φόντα",
    "No audio" : "Χωρίς ήχο",
    "No camera" : "Χωρίς κάμερα",
    "Display video as you will see it (mirrored)" : "Εμφάνιση βίντεο όπως θα το δείτε (καθρεφτισμένο)",
    "Display video as others will see it" : "Εμφάνιση βίντεο όπως θα το δουν οι άλλοι",
    "Calls are not supported in your browser" : "Οι κλήσεις δεν υποστηρίζονται στον περιηγητή σας.",
    "Access to microphone is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο είναι εφικτή μόνο μέσω HTTPS.",
    "Access to microphone was denied" : "Δεν επιτρέπεται η πρόσβαση στο μικρόφωνο",
    "Error while accessing microphone" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο.",
    "Access to camera is only possible with HTTPS" : "Η πρόσβαση στην κάμερα είναι εφικτή μόνο μέσω HTTPS.",
    "The call is being recorded." : "Η κλήση καταγράφεται.",
    "The call might be recorded." : "Η κλήση μπορεί να καταγράφεται.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Η εγγραφή μπορεί να περιλαμβάνει τη φωνή σας, βίντεο από την κάμερα και κοινή χρήση οθόνης. Απαιτείται η συγκατάθεσή σας πριν από τη συμμετοχή στην κλήση.",
    "Give consent to the recording of this call" : "Δώστε συγκατάθεση για την εγγραφή αυτής της κλήσης",
    "Show more info" : "Εμφάνιση περισσότερων πληροφοριών",
    "Audio is not available" : "Ο ήχος δεν είναι διαθέσιμος",
    "Video is not available" : "Το βίντεο δεν είναι διαθέσιμο",
    "Start recording immediately with the call" : "Έναρξη εγγραφής αμέσως με την κλήση",
    "Notify all participants about this call" : "Ειδοποίηση όλων των συμμετεχόντων για αυτήν την κλήση",
    "Apply settings" : "Εφαρμογή ρυθμίσεων",
    "Select virtual office background" : "Επιλογή εικονικού φόντου γραφείου",
    "Select virtual home background" : "Επιλογή εικονικού φόντου σπιτιού",
    "Select virtual abstract background" : "Επιλογή εικονικού αφηρημένου φόντου",
    "Select virtual beach background" : "Επιλογή εικονικού φόντου παραλίας",
    "Select virtual park background" : "Επιλογή εικονικού φόντου πάρκου",
    "Select virtual theater background" : "Επιλογή εικονικού φόντου θεάτρου",
    "Select virtual library background" : "Επιλογή εικονικού φόντου βιβλιοθήκης",
    "Select virtual space station background" : "Επιλογή εικονικού φόντου διαστημικού σταθμού",
    "Error while uploading the file" : "Σφάλμα κατά τη μεταφόρτωση του αρχείου",
    "Select a file" : "Επιλογή αρχείου",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Select virtual background from file {fileName}" : "Επιλογή εικονικού φόντου από το αρχείο {fileName}",
    "Blur" : "Θόλωμα",
    "Upload" : "Μεταφόρτωση",
    "Files" : "Αρχεία",
    "(editing)" : "(επεξεργασία)",
    "(edited)" : "(επεξεργασμένο)",
    "The message has expired or has been deleted" : "Το μήνυμα έχει λήξει ή έχει διαγραφεί",
    "Cancel quote" : "Ακύρωση παράθεσης",
    "24 hours" : "24 ώρες",
    "7 days" : "7 ημέρες",
    "Clear reminder – {timeLocale}" : "Εκκαθάριση υπενθύμισης – {timeLocale}",
    "Edited by {actor}" : "Επεξεργάστηκε από {actor}",
    "Message text copied to clipboard" : "Το κείμενο του μηνύματος αντιγράφηκε στο πρόχειρο",
    "Message text could not be copied" : "Το κείμενο του μηνύματος δεν μπορούσε να αντιγραφεί",
    "Message forwarded to \"Note to self\"" : "Το μήνυμα προωθήθηκε στο \"Σημείωση προς εμένα\"",
    "Error while forwarding message to \"Note to self\"" : "Σφάλμα κατά την προώθηση του μηνύματος στο \"Σημείωση προς εμένα\"",
    "A reminder was successfully removed" : "Μια υπενθύμιση αφαιρέθηκε με επιτυχία",
    "Error occurred when removing a reminder" : "Παρουσιάστηκε σφάλμα κατά την αφαίρεση μιας υπενθύμισης",
    "A reminder was successfully set at {datetime}" : "Μια υπενθύμιση ορίστηκε με επιτυχία στις {datetime}",
    "Error occurred when creating a reminder" : "Παρουσιάστηκε σφάλμα κατά τη δημιουργία μιας υπενθύμισης",
    "Add a reaction to this message" : "Προσθήκη αντίδρασης σε αυτό το μήνυμα",
    "Reply" : "Απάντηση",
    "More actions" : "Περισσότερες ενέργειες",
    "Set reminder" : "Προσθήκη υπενθύμισης",
    "Reply privately" : "Απάντηση ιδιωτικά",
    "Edit message" : "Επεξεργασία μηνύματος",
    "Copy message" : "Αντιγραφή μηνύματος",
    "Copy message link" : "Αντιγραφή συνδέσμου μηνύματος",
    "Go to file" : "Μετάβαση στο αρχείο",
    "Download file" : "Λήψη αρχείου",
    "Go to thread" : "Μετάβαση στη συζήτηση",
    "Edit thread details" : "Επεξεργασία λεπτομερειών συζήτησης",
    "Forward message" : "Προώθηση μηνύματος",
    "Translate" : "Μετάφραση",
    "Set custom reminder" : "Ορισμός προσαρμοσμένης υπενθύμισης",
    "Close reactions menu" : "Κλείσιμο μενού αντιδράσεων",
    "React with {emoji}" : "Αντίδραση με {emoji}",
    "React with another emoji" : "Αντίδραση με άλλο emoji",
    "Choose a conversation to forward the selected message." : "Επιλέξτε μια συνομιλία για να προωθήσετε το επιλεγμένο μήνυμα.",
    "Error while forwarding message" : "Σφάλμα κατά την προώθηση μηνύματος",
    "The message has been forwarded to {selectedConversationName}" : "Το μήνυμα έχει προωθηθεί στο {selectedConversationName}",
    "Dismiss" : "Αποδέσμευση",
    "Go to conversation" : "Μετάβαση στη συνομιλία",
    "Detect language" : "Ανίχνευση γλώσσας",
    "The message could not be translated" : "Δεν ήταν δυνατή η μετάφραση του μηνύματος",
    "Translation copied to clipboard" : "Η μετάφραση αντιγράφηκε στο πρόχειρο",
    "Translation could not be copied" : "Δεν ήταν δυνατή η αντιγραφή της μετάφρασης",
    "Translate message" : "Μετάφραση μηνύματος",
    "Source language to translate from" : "Γλώσσα πηγής για μετάφραση από",
    "Translate from" : "Μετάφραση από",
    "Target language to translate into" : "Γλώσσα προορισμού για μετάφραση σε",
    "Translate to" : "Μετάφραση σε",
    "Translating" : "Μεταφράζεται",
    "Copy translated text" : "Αντιγραφή μεταφρασμένου κειμένου",
    "Send now" : "Αποστολή τωρα",
    "Message read by everyone who shares their reading status" : "Το μήνυμα διαβάστηκε από όλους όσους μοιράζονται την κατάσταση ανάγνωσής τους",
    "Message sent" : "Το μήνυμα στάλθηκε",
    "Sent without notification" : "Αποστολή χωρίς ειδοποίηση",
    "Deleting message" : "Γίνεται διαγραφή μηνύματος",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Το μήνυμα διαγράφηκε με επιτυχία, αλλά έχει ρυθμιστεί ένα bot ή Matterbridge και το μήνυμα μπορεί να έχει ήδη διανεμηθεί σε άλλες υπηρεσίες",
    "Message deleted successfully" : "Το μήνυμα διαγράφηκε με επιτυχία",
    "Message could not be deleted because it is too old" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος επειδή είναι αρκετά παλιό",
    "Only normal chat messages can be deleted" : "Μόνο τα κανονικά μηνύματα συνομιλίας μπορούν να διαγραφούν",
    "An error occurred while deleting the message" : "Προέκυψε ένα σφάλμα κατά τη διαγραφή του μηνύματος",
    "Your browser does not support playing audio files" : "Το πρόγραμμα περιήγησής σας δεν υποστηρίζει την αναπαραγωγή αρχείων ήχου",
    "Contact" : "Επικοινωνία",
    "{stack} in {board}" : "{stack} στο {board}",
    "Deck Card" : "Κάρτα Deck",
    "Remove {fileName}" : "Αφαίρεση {fileName}",
    "Open this location in OpenStreetMap" : "Άνοιγμα αυτής της τοποθεσίας στο OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n απάντηση","%n απαντήσεις"],
    "Sending message" : "Αποστολή μηνύματος",
    "Failed to send the message. Click to try again" : "Αποτυχία αποστολής του μηνύματος. Κάντε κλικ για να δοκιμάσετε ξανά",
    "Not enough free space to upload file" : "Δεν επαρκεί ο ελεύθερος χώρος για τη μεταφόρτωση του αρχείου",
    "You cannot send messages to this conversation at the moment" : "Δεν μπορείτε να στείλετε μηνύματα σε αυτή τη συνομιλία αυτή τη στιγμή",
    "Could not update the message" : "Δεν ήταν δυνατή η ενημέρωση του μηνύματος",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Προσχέδιο δημοσκόπησης • %n επιλογή","Προσχέδιο δημοσκόπησης • %n επιλογές"],
    "Edit poll draft" : "Επεξεργασία προσχεδίου δημοσκόπησης",
    "Delete poll draft" : "Διαγραφή προσχεδίου δημοσκόπησης",
    "Open poll" : "Ανοιχτή δημοσκόπηση",
    "See results" : "Προβολή αποτελεσμάτων",
    "Reactions" : "Αντιδράσεις",
    "No permission to post reactions in this conversation" : "Δεν υπάρχει άδεια δημοσίευσης αντιδράσεων σε αυτή τη συνομιλία",
    "and {participant}" : "και {participant}",
    "_and %n other participant_::_and %n other participants_" : ["και %n άλλος συμμετέχων","και %n άλλοι συμμετέχοντες"],
    "Show all reactions" : "Εμφάνιση όλων των αντιδράσεων",
    "Add more reactions" : "Προσθήκη περισσότερων αντιδράσεων",
    "Show or collapse system messages" : "Εμφάνιση ή σύμπτυξη μηνυμάτων συστήματος",
    "No messages" : "Κανένα μήνυμα",
    "All messages have expired or have been deleted." : "Όλα τα μηνύματα έχουν λήξει ή έχουν διαγραφεί.",
    "Unpin" : "Ξεκαρφίτσωμα",
    "Cancel search" : "Ακύρωση αναζήτησης",
    "Add a phone number" : "Προσθήκη αριθμού τηλεφώνου",
    "Error: A password is required to create the conversation." : "Σφάλμα: Απαιτείται κωδικός πρόσβασης για τη δημιουργία της συνομιλίας.",
    "All set, the conversation \"{conversationName}\" was created." : "Όλα έτοιμα, η συνομιλία \"{conversationName}\" δημιουργήθηκε.",
    "Create a new group conversation" : "Δημιουργία νέας ομαδικής συζήτησης",
    "Add participants" : "Προσθήκη συμμετεχόντων",
    "Maximum length exceeded ({maxlength} characters)" : "Υπέρβαση μέγιστου μήκους ({maxlength} χαρακτήρες)",
    "Conversation visibility" : "Ορατότητα συνομιλίας",
    "Allow guests to join via link" : "Να επιτρέπεται σε επισκέπτες να συμμετέχουν μέσω συνδέσμου",
    "Enter password" : "Εισάγετε συνθηματικό",
    "This conversation has been locked" : "Αυτή η συνομιλία έχει κλειδωθεί",
    "No permission to post messages in this conversation" : "Δεν επιτρέπεται η δημοσίευση μηνυμάτων σε αυτήν τη συνομιλία",
    "Joining conversation …" : "Συμμετοχή σε συνομιλία…",
    "Write a message without notification" : "Γράψτε ένα μήνυμα χωρίς ειδοποίηση",
    "Create a thread silently" : "Δημιουργία συζήτησης σιωπηλά",
    "Create a thread" : "Δημιουργία συζήτησης",
    "Send message silently" : "Αποστολή μηνύματος σιωπηλά",
    "Send message" : "Αποστολή μηνύματος",
    "Send without notification" : "Αποστολή χωρίς ειδοποίηση",
    "The participant will not be notified about new messages" : "Ο συμμετέχων δεν θα ειδοποιηθεί για νέα μηνύματα",
    "Participants will not be notified about new messages" : "Οι συμμετέχοντες δεν θα ειδοποιηθούν για νέα μηνύματα",
    "Thread title is required" : "Απαιτείται τίτλος συζήτησης",
    "Message text is required" : "Απαιτείται κείμενο μηνύματος",
    "The message could not be edited" : "Δεν ήταν δυνατή η επεξεργασία του μηνύματος",
    "File to share" : "Αρχείο για διαμοιρασμό",
    "File upload is not available in this conversation" : "Η μεταφόρτωση αρχείων δεν είναι διαθέσιμη σε αυτή τη συνομιλία",
    "Add emoji" : "Προσθήκη emoji",
    "Adding a mention will only notify users who did not read the message." : "Η προσθήκη αναφοράς θα ειδοποιήσει μόνο χρήστες που δεν έχουν διαβάσει το μήνυμα.",
    "Thread title" : "Τίτλος συζήτησης",
    "Send later" : "Αποστολή αργότερα",
    "Cancel editing" : "Ακύρωση επεξεργασίας",
    "{user} is out of office and might not respond." : "Ο {user} είναι εκτός γραφείου και μπορεί να μην απαντήσει.",
    "Absence period: {startDate} - {endDate}" : "Περίοδος απουσίας: {startDate} - {endDate}",
    "Replacement:" : "Αντικαταστάτης:",
    "Share from {nextcloud}" : "Κοινή χρήση από {nextcloud}",
    "Share from Files" : "Κοινή χρήση από Αρχεία",
    "Share files to the conversation" : "Διαμοιρασμός αρχείων στην συνομιλία",
    "Upload from device" : "Μεταφόρτωση από συσκευή",
    "Create new poll" : "Δημιουργία νέας ψηφοφορίας",
    "Smart picker" : "Έξυπνος επιλογέας",
    "Record voice message" : "Εγγραφή φωνητικού μηνύματος",
    "End recording and send" : "Τερματισμός εγγραφής και αποστολή",
    "Dismiss recording" : "Απόρριψη εγγραφής",
    "Access to the microphone was denied" : "Η πρόσβαση στο μικρόφωνο απορρίφθηκε",
    "Microphone either not available or disabled in settings" : "Το μικρόφωνο δεν είναι διαθέσιμο ή είναι απενεργοποιημένο στις ρυθμίσεις",
    "Error while recording audio" : "Σφάλμα κατά την εγγραφή ήχου",
    "Generating summary of unread messages …" : "Δημιουργία σύνοψης μη αναγνωσμένων μηνυμάτων …",
    "Summary is AI generated and might contain mistakes" : "Η σύνοψη δημιουργείται από τεχνητή νοημοσύνη και μπορεί να περιέχει λάθη",
    "Error occurred during a summary generation" : "Παρουσιάστηκε σφάλμα κατά τη δημιουργία σύνοψης",
    "New file" : "Νέο αρχείο",
    "Blank" : "Κενό",
    "Error while creating file" : "Σφάλμα κατά τη δημιουργία αρχείου",
    "Create and share a new file" : "Δημιουργία και κοινή χρήση νέου αρχείου",
    "Name of the new file" : "Όνομα του νέου αρχείου",
    "Create file" : "Δημιουργία αρχείου",
    "Someone is typing …" : "Κάποιος πληκτρολογεί …",
    "{user1} is typing …" : "Ο {user1} πληκτρολογεί …",
    "{user1} and {user2} are typing …" : "Οι {user1} και {user2} πληκτρολογούν …",
    "{user1}, {user2} and {user3} are typing …" : "Οι {user1}, {user2} και {user3} πληκτρολογούν …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["Οι {user1}, {user2}, {user3} και %n άλλος πληκτρολογούν …","Οι {user1}, {user2}, {user3} και %n άλλοι πληκτρολογούν …"],
    "Add more files" : "Προσθήκη περισσότερων αρχείων",
    "Send" : "Αποστολή",
    "In this conversation <strong>{user}</strong> can:" : "Σε αυτή τη συνομιλία ο <strong>{user}</strong> μπορεί:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Επεξεργασία προεπιλεγμένων δικαιωμάτων για συμμετέχοντες στο <strong>{conversationName}</strong>",
    "Start a call" : "Έναρξη κλήσης",
    "Skip the lobby" : "Παράκαμψη της αίθουσας αναμονής",
    "Can post messages and reactions" : "Μπορεί να δημοσιεύει μηνύματα και αντιδράσεις",
    "Enable the microphone" : "Ενεργοποίηση μικροφώνου",
    "Enable the camera" : "Ενεργοποίηση κάμερας",
    "Share the screen" : "Κοινή χρήση οθόνης",
    "Update permissions" : "Ενημέρωση αδειών",
    "Updating permissions" : "Ενημέρωση δικαιωμάτων",
    "No poll drafts" : "Δεν υπάρχουν προσχέδια δημοσκοπήσεων",
    "There is no poll drafts yet saved for this conversation" : "Δεν υπάρχουν ακόμη αποθηκευμένα προσχέδια δημοσκοπήσεων για αυτή τη συνομιλία",
    "Create poll in {name}" : "Δημιουργία δημοσκόπησης στο {name}",
    "Create poll" : "Δημιουργία ψηφοφορίας",
    "Error while importing poll" : "Σφάλμα κατά την εισαγωγή δημοσκόπησης",
    "Question" : "Ερώτηση",
    "Ask a question" : "Κάντε μια ερώτηση",
    "Import draft from file" : "Εισαγωγή προσχεδίου από αρχείο",
    "Answers" : "Απαντήσεις",
    "Answer {option}" : "Απάντηση {option}",
    "Delete poll option" : "Διαγραφή επιλογής δημοσκόπησης",
    "Add answer" : "Προσθήκη απάντησης",
    "Settings" : "Ρυθμίσεις",
    "Anonymous poll" : "Ανώνυμη δημοσκόπηση",
    "Multiple answers" : "Πολλαπλές απαντήσεις",
    "Save as draft" : "Αποθήκευση ως προσχέδιο",
    "Export draft to file" : "Εξαγωγή προσχεδίου σε αρχείο",
    "You voted for this option" : "Ψηφίσατε για αυτή την επιλογή",
    "End poll" : "Τερματισμός δημοσκόπησης",
    "Change your vote" : "Αλλαγή ψήφου σας",
    "Results" : "Αποτελέσματα",
    "Voted participants" : "Συμμετέχοντες που ψήφισαν",
    "Send a message to \"{roomName}\"" : "Αποστολή μηνύματος στο \"{roomName}\"",
    "Hide list of participants" : "Απόκρυψη λίστας συμμετεχόντων",
    "Show list of participants" : "Εμφάνιση λίστας συμμετεχόντων",
    "Assistance requested in {roomName}" : "Ζητήθηκε βοήθεια στο {roomName}",
    "The message was sent to \"{roomName}\"" : "Το μήνυμα στάλθηκε στο \"{roomName}\"",
    "Dismiss request for assistance" : "Απόρριψη αιτήματος βοήθειας",
    "Send message to room" : "Αποστολή μηνύματος στην αίθουσα",
    "Back to main room" : "Επιστροφή στην κύρια αίθουσα",
    "Back to your room" : "Επιστροφή στο δωμάτιό σας",
    "Message all rooms" : "Μήνυμα σε όλα τα δωμάτια",
    "Start session" : "Έναρξη συνεδρίας",
    "Start a call before you start a breakout room session" : "Ξεκινήστε μια κλήση πριν ξεκινήσετε μια συνεδρία δωματίων διάσπασης",
    "Stop session" : "Διακοπή συνεδρίας",
    "The message was sent to all breakout rooms" : "Το μήνυμα στάλθηκε σε όλα τα δωμάτια διάσπασης",
    "Send a message to all breakout rooms" : "Αποστολή μηνύματος σε όλα τα δωμάτια διάσπασης",
    "Breakout rooms are not started" : "Τα δωμάτια διάσπασης δεν έχουν ξεκινήσει",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Οι κλήσεις χωρίς υψηλής απόδοσης backend μπορεί να προκαλέσουν προβλήματα σύνδεσης και υψηλό φόρτο σε συσκευές. {linkstart}Μάθετε περισσότερα{linkend}",
    "Talk setup incomplete" : "Η ρύθμιση ομιλίας είναι ελλιπής",
    "Disable lobby" : "Απενεργοποίηση αίθουσας αναμονής",
    "Settings for participant \"{user}\"" : "Ρυθμίσεις για συμμετέχοντα \"{user}\"",
    "Participant \"{user}\"" : "Συμμετέχων \"{user}\"",
    "moderator" : "συντονιστής",
    "bot" : "bot",
    "guest" : "Επισκέπτης",
    "Ringing …" : "Χτυπάει …",
    "Call rejected" : "Η κλήση απορρίφθηκε",
    "{time} talking …" : "{time} ομιλία …",
    "{time} talking time" : "{time} χρόνος ομιλίας",
    "Raised their hand" : "Σήκωσαν το χέρι τους",
    "Joined with video" : "Συμμετοχή με βίντεο",
    "Joined via phone" : "Συμμετοχή μέσω τηλεφώνου",
    "Joined with audio" : "Συμμετοχή με ήχο",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Το κείμενο πρέπει να είναι μικρότερο ή ίσο με {maxLength} χαρακτήρες. Το τρέχον κείμενό σας είναι {charactersCount} χαρακτήρες.",
    "Remove group and members" : "Αφαίρεση ομάδας και μελών",
    "Remove team and members" : "Αφαίρεση ομάδας και μελών",
    "Remove participant" : "Αφαίρεση συμμετέχοντα",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Θέλετε πραγματικά να αφαιρέσετε την ομάδα \"{displayName}\" και τα μέλη της από αυτή τη συνομιλία;",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Θέλετε πραγματικά να αφαιρέσετε την ομάδα \"{displayName}\" και τα μέλη της από αυτή τη συνομιλία;",
    "Do you really want to remove {displayName} from this conversation?" : "Θέλετε πραγματικά να αφαιρέσετε τον {displayName} από αυτή τη συνομιλία;",
    "Notification was sent to {displayName}" : "Η ειδοποίηση στάλθηκε στον {displayName}",
    "Could not send notification to {displayName}" : "Δεν ήταν δυνατή η αποστολή ειδοποίησης στον {displayName}",
    "Permissions granted to {displayName}" : "Δικαιώματα που παραχωρήθηκαν στον {displayName}",
    "Could not modify permissions for {displayName}" : "Δεν ήταν δυνατή η τροποποίηση δικαιωμάτων για τον {displayName}",
    "Permissions removed for {displayName}" : "Δικαιώματα που αφαιρέθηκαν από τον {displayName}",
    "Permissions set to default for {displayName}" : "Δικαιώματα που ορίστηκαν σε προεπιλογή για τον {displayName}",
    "Phone number could not be hung up" : "Ο αριθμός τηλεφώνου δεν μπορούσε να κλείσει",
    "Phone number could not be put on hold" : "Ο αριθμός τηλεφώνου δεν μπορούσε να τεθεί σε αναμονή",
    "Phone number could not be muted" : "Ο αριθμός τηλεφώνου δεν μπορούσε να σιγαστεί",
    "Phone number could not be unmuted" : "Ο αριθμός τηλεφώνου δεν μπορούσε να ξεσιγαστεί",
    "DTMF message could not be sent" : "Το μήνυμα DTMF δεν μπορούσε να αποσταλεί",
    "Phone number copied to clipboard" : "Ο αριθμός τηλεφώνου αντιγράφηκε στο πρόχειρο",
    "Phone number could not be copied" : "Ο αριθμός τηλεφώνου δεν μπορούσε να αντιγραφεί",
    "in the lobby" : "στην αίθουσα αναμονής",
    "Dial out phone" : "Κλήση εξωτερικού τηλεφώνου",
    "Hang up phone" : "Κλείσιμο τηλεφώνου",
    "Move back to lobby" : "Επιστροφή στην αίθουσα αναμονής",
    "Move to conversation" : "Μετάβαση σε συνομιλία",
    "Dial-in PIN" : "PIN σύνδεσης",
    "Demote from moderator" : "Υποβάθμιση από συντονιστή",
    "Promote to moderator" : "Προαγωγή από συντονιστή",
    "Resend invitation" : "Επαναποστολή πρόσκλησης",
    "Send call notification" : "Αποστολή ειδοποίησης κλήσης",
    "Dial out phone number" : "Κλήση εξωτερικού αριθμού τηλεφώνου",
    "Resume call for phone number" : "Συνέχιση κλήσης για αριθμό τηλεφώνου",
    "Put phone number on hold" : "Τοποθέτηση αριθμού τηλεφώνου σε αναμονή",
    "Unmute phone number" : "Αποσιγόπηση αριθμού τηλεφώνου",
    "Mute phone number" : "Σίγαση αριθμού τηλεφώνου",
    "Copy phone number" : "Αντιγραφή αριθμού τηλεφώνου",
    "Reset custom permissions" : "Επαναφορά προσαρμοσμένων δικαιωμάτων",
    "Grant all permissions" : "Χορήγηση όλων των δικαιωμάτων",
    "Remove all permissions" : "Αφαίρεση όλων των δικαιωμάτων",
    "Also ban from this conversation" : "Αποκλεισμός και από αυτή τη συνομιλία",
    "Internal note (reason to ban)" : "Εσωτερική σημείωση (λόγος αποκλεισμού)",
    "Remove" : "Αφαίρεση",
    "Permissions modified for {displayName}" : "Τα δικαιώματα τροποποιήθηκαν για τον {displayName}",
    "Add users, groups or teams" : "Προσθήκη χρηστών, ομάδων ή ομάδων",
    "Add users or groups" : "Προσθήκη χρηστών ή ομάδων",
    "Add users or teams" : "Προσθήκη χρηστών ή ομάδων",
    "Add users" : "Προσθήκη χρηστών",
    "Add groups or teams" : "Προσθήκη ομάδων ή ομάδων",
    "Add groups" : "Προσθήκη ομάδων",
    "Add teams" : "Προσθήκη ομάδων",
    "Add other sources" : "Προσθήκη άλλων πηγών",
    "Add emails" : "Προσθήκη emails",
    "Integrations" : "Ενσωματώσεις",
    "Add federated users" : "Προσθήκη ομοσπονδιακών χρηστών",
    "Searching …" : "Αναζήτηση ...",
    "Search for more users" : "Αναζήτηση περισσότερων χρηστών",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Μπορείτε να αναζητήσετε ή να προσθέσετε συμμετέχοντες μέσω ονόματος, email ή Federated Cloud ID",
    "Search or add participants" : "Αναζήτηση ή προσθήκη συμμετεχόντων",
    "Invitation was sent to {actorId}" : "Η πρόσκληση στάλθηκε στον {actorId}",
    "An error occurred while adding the participants" : "Παρουσιάστηκε σφάλμα κατά την προσθήκη των συμμετεχόντων",
    "A new group conversation with selected participant will be created" : "Θα δημιουργηθεί μια νέα ομαδική συνομιλία με τον επιλεγμένο συμμετέχοντα",
    "Participants" : "Συμμετέχοντες",
    "Participants ({count})" : "Συμμετέχοντες ({count})",
    "Open chat" : "Άνοιγμα συνομιλίας",
    "You have new unread messages in the chat." : "Έχετε νέα μη αναγνωσμένα μηνύματα στη συνομιλία.",
    "You have been mentioned in the chat." : "Έχετε αναφερθεί στη συνομιλία.",
    "Search messages" : "Αναζήτηση μηνυμάτων",
    "Chat" : "Συνομιλία",
    "Details" : "Λεπτομέρειες",
    "Shared items" : "Κοινόχρηστα αντικείμενα",
    "Search in {name}" : "Αναζήτηση στο {name}",
    "Threads in {name}" : "Συζητήσεις στο {name}",
    "{actor} in {conversation}" : "{actor} στο {conversation}",
    "Search messages …" : "Αναζήτηση μηνυμάτων …",
    "Search options" : "Επιλογές αναζήτησης",
    "From User" : "Από Χρήστη",
    "Since" : "Από",
    "Until" : "Μέχρι",
    "No results found" : "Δεν βρέθηκαν αποτελέσματα",
    "Load more results" : "Φόρτωση περισσοτέρων αποτελεσμάτων",
    "Recent threads" : "Πρόσφατες συζητήσεις",
    "Projects" : "Έργα",
    "No shared items" : "Δεν υπάρχουν κοινόχρηστα αντικείμενα",
    "Thread notifications" : "Ειδοποιήσεις συζήτησης",
    "Thread actions" : "Ενέργειες συζήτησης",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Σύνδεσμος συνομιλίας",
    "No open conversations found" : "Δεν βρέθηκαν ανοιχτές συνομιλίες",
    "Either there are no open conversations or you joined all of them." : "Είτε δεν υπάρχουν ανοιχτές συνομιλίες είτε έχετε συμμετάσχει σε όλες.",
    "Check spelling or use complete words." : "Ελέγξτε την ορθογραφία ή χρησιμοποιήστε πλήρεις λέξεις.",
    "Search conversations or users" : "Αναζήτηση συνομιλιών ή χρηστών",
    "Select conversation" : "Επιλέξτε συνομιλία",
    "Number length is not valid" : "Το μήκος του αριθμού δεν είναι έγκυρο",
    "Region code is not valid" : "Ο κωδικός περιοχής δεν είναι έγκυρος",
    "Number length is too short" : "Το μήκος του αριθμού είναι πολύ μικρό",
    "Number length is too long" : "Το μήκος του αριθμού είναι πολύ μεγάλο",
    "Number is not valid" : "Ο αριθμός δεν είναι έγκυρος",
    "Phone numbers" : "Αριθμοί τηλεφώνου",
    "Display name: {name}" : "Εμφανιζόμενο όνομα: {name}",
    "Edit display name" : "Επεξεργασία εμφανιζόμενου ονόματος",
    "Display name (required)" : "Εμφανιζόμενο όνομα (απαιτείται)",
    "Save name" : "Αποθήκευση ονόματος",
    "Error while setting personal setting" : "Σφάλμα κατά τον ορισμό προσωπικής ρύθμισης",
    "Error while saving sounds setting" : "Σφάλμα κατά την αποθήκευση της ρύθμισης ήχων",
    "Play sounds when participants join or leave a call" : "Αναπαραγωγή ήχων όταν οι συμμετέχοντες εισέρχονται ή αποχωρούν από μια κλήση",
    "Notification settings" : "Ρυθμίσεις ειδοποιήσεων",
    "Default language" : "Προεπιλεγμένη γλώσσα",
    "Select location for attachments" : "Επιλέξτε τοποθεσία για τα συνημμένα",
    "Error while setting attachment folder" : "Σφάλμα κατά την ρύθμιση φακέλου συνημμένων",
    "Error while setting read status privacy" : "Σφάλμα κατά τον ορισμό απορρήτου κατάστασης ανάγνωσης",
    "Error while setting typing status privacy" : "Σφάλμα κατά τον ορισμό απορρήτου κατάστασης πληκτρολόγησης",
    "Error while setting default media state" : "Σφάλμα κατά τη ρύθμιση της προεπιλεγμένης κατάστασης πολυμέσων",
    "Privacy" : "Ιδιωτικότητα",
    "Attachments folder" : "Φάκελος συνημμένων",
    "Toggle full screen" : "Εναλλαγή πλήρους οθόνης",
    "Search" : "Αναζήτηση",
    "Focus the chat input" : "Εστίασε την είσοδο συνομιλίας",
    "Unfocus the chat input to use shortcuts" : "Αποεπιλέξτε την είσοδο συνομιλίας για να χρησιμοποιήσετε συντομεύσεις",
    "Edit your last message" : "Επεξεργασία του τελευταίου μηνύματός σας",
    "Shortcuts while in a call" : "Συντομεύσεις κατά τη διάρκεια μιας κλήσης",
    "Camera on and off" : "Ενεργοποίηση και απενεργοποίηση κάμερας",
    "Microphone on and off" : "Ενεργοποίηση και απενεργοποίηση μικροφώνου",
    "Raise or lower hand" : "Σηκώστε ή κατεβάστε το χέρι",
    "Push to talk or push to mute" : "Πιέστε για να μιλήσετε ή πιέστε για σίγαση",
    "Zoom-in / zoom-out a screen share" : "Εστίαση / απομάκρυνση κοινής χρήσης οθόνης",
    "Mouse wheel" : "Τροχός ποντικιού",
    "Start call silently" : "Έναρξη κλήσης σιωπηλά",
    "Start call" : "Έναρξη κλήσης",
    "End call" : "Τερματισμός κλήσης",
    "This call has just ended" : "Αυτή η κλήση μόλις τελείωσε",
    "You will be able to join the call only after a moderator starts it." : "Μπορείτε να συμμετάσχετε στην κλήση μόνο μετά την εκκίνηση από τον συντονιστή.",
    "End call for everyone" : "Τερματισμός κλήσης για όλους",
    "Starting the recording" : "Έναρξη εγγραφής",
    "Recording" : "Καταγραφή",
    "The call has been running for one hour." : "Η κλήση εκτελείται για μία ώρα.",
    "Cancel recording start" : "Ακύρωση έναρξης εγγραφής",
    "Stop recording" : "Διακοπή εγγραφής",
    "Send a reaction" : "Αποστολή αντίδρασης",
    "React with {reaction}" : "Αντίδραση με {reaction}",
    "All tasks done!" : "Όλες οι εργασίες ολοκληρώθηκαν!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} από %n εργασία","{done} από %n εργασίες"],
    "Add participants to this call" : "Προσθήκη συμμετεχόντων σε αυτήν την κλήση",
    "_%n participant in call_::_%n participants in call_" : ["%n συμμετέχων στην κλήση","%n συμμετέχοντες στην κλήση"],
    "You are not allowed to enable screensharing" : "Δεν επιτρέπεται να ενεργοποιήσετε τον διαμοιρασμό οθόνης",
    "No screensharing" : "Δεν υπάρχει διαμοιρασμός οθόνης",
    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
    "Bad sent video and screen quality." : "Κακή ποιότητα βίντεο και διαμοιρασμού οθόνης.",
    "Bad sent screen quality." : "Κακή ποιότητα διαμοιρασμού οθόνης.",
    "Bad sent video quality." : "Κακή ποιότητα βίντεο.",
    "Bad sent audio, video and screen quality." : "Κακή ποιότητα ήχου, βίντεο και διαμοιρασμού οθόνης.",
    "Bad sent audio and screen quality." : "Κακή ποιότητα ήχου και διαμοιρασμού οθόνης.",
    "Bad sent audio and video quality." : "Κακή ποιότητα ήχου και βίντεο.",
    "Bad sent audio quality." : "Κακή ποιότητα ήχου.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να δουν την οθόνη σας. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το θόλωμα φόντου ή το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
    "Disable background blur" : "Απενεργοποίηση θολώματος φόντου",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να δουν την οθόνη σας. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να δουν την οθόνη σας.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας δουν.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το θόλωμα φόντου ή το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να δουν την οθόνη σας. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε τον διαμοιρασμό οθόνης σας.",
    "Disable screenshare" : "Απενεργοποίηση του διαμοιρασμού οθόνης",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το θόλωμα φόντου ή το βίντεό σας.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν.",
    "Screen sharing is not supported by your browser." : "Η κοινή χρήση οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η χρήση σελίδας με HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
    "Select virtual background" : "Επιλογή εικονικού φόντου",
    "Show your screen" : "Εμφάνιση της οθόνης σας",
    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
    "Mute others" : "Σίγαση των άλλων",
    "Start recording" : "Έναρξη εγγραφής",
    "Set up breakout rooms" : "Ρύθμιση δωματίων διάσπασης",
    "Download attendance list" : "Λήψη λίστας παρουσιών",
    "Open Calendar" : "Άνοιγμα Ημερολογίου",
    "Remove participant {name}" : "Αφαίρεση συμμετέχοντα {name}",
    "Would you like to delete this conversation?" : "Θέλετε να διαγράψετε αυτή τη συνομιλία;",
    "Are you sure you want to delete this conversation?" : "Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή τη συνομιλία;",
    "Delete now" : "Διαγραφή τώρα",
    "Keep" : "Διατήρηση",
    "Open dialpad" : "Άνοιγμα πληκτρολογίου",
    "Select a region" : "Επιλογή περιοχής",
    "Local time: {time}" : "Τοπική ώρα: {time}",
    "Search …" : "Αναζήτηση …",
    "Message without mention" : "Μήνυμα χωρίς αναφορά σε κάποιον",
    "Mention myself" : "Αναφορά στον εαυτό μου",
    "Mention everyone" : "Αναφορά σε όλους",
    "Select a conversation" : "Επιλέξτε μια συνομιλία",
    "Select a mode" : "Επιλέξτε μια λειτουργία",
    "You do not have permissions to access this conversation." : "Δεν έχετε δικαιώματα πρόσβασης σε αυτή τη συνομιλία.",
    "Join a different conversation or start a new one." : "Συμμετέχετε σε διαφορετική συνομιλία ή ξεκινήστε μια νέα.",
    "The conversation does not exist" : "Η συνομιλία δεν υπάρχει",
    "Join a conversation or start a new one!" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα!",
    "Duplicate session" : "Αντιγραφή συνεδρίας",
    "Creating and joining a conversation with \"{userid}\"" : "Δημιουργία και συμμετοχή σε συνομιλία με \"{userid}\"",
    "Join a conversation or start a new one" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα",
    "Error while joining the conversation" : "Σφάλμα κατά τη συμμετοχή στη συνομιλία",
    "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
    "Nextcloud user" : "Χρήστης του Nextcloud",
    "User password" : "Συνθηματικό χρήστη",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Skip TLS verification" : "Παράλειψη επαλήθευσης TLS",
    "Matrix server URL" : "Διεύθυνση URL διακομιστή Matrix",
    "User" : "Χρήστης",
    "Matrix channel" : "Κανάλι Matrix",
    "Mattermost server URL" : "Διεύθυνση URL διακομιστή Mattermost",
    "Mattermost user" : "Χρήστης Mattermost",
    "Team name" : "Όνομα ομάδας",
    "Channel name" : "Όνομα καναλιού",
    "Rocket.Chat server URL" : "Διεύθυνση URL διακομιστή Rocket.Chat",
    "User name or email address" : "Όνομα χρήστη ή διεύθυνση email",
    "Rocket.Chat channel" : "Κανάλι Rocket.Chat",
    "Zulip server URL" : "Διεύθυνση URL διακομιστή Zulip",
    "Bot user name" : "Όνομα χρήστη του ρομπότ",
    "Bot API key" : "Κλειδί API του ρομπότ",
    "Zulip channel" : "Κανάλι Zulip",
    "API token" : "Διακριτικό API",
    "Slack channel" : "Κανάλι Slack",
    "Server ID or name" : "Όνομα ή ταυτότητα διακομιστή",
    "Channel ID (prefixed with \"ID:\") or name" : "Αναγνωριστικό καναλιού (με πρόθεμα \"ID:\") ή όνομα",
    "Channel" : "Κανάλι",
    "Login" : "Είσοδος",
    "Chat ID" : "Αναγνωριστικό συνομιλίας",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL διακομιστή IRC (πχ chat.freenode.net:6667)",
    "Nickname" : "Παρατσούκλι",
    "Connection password" : "Κωδικός πρόσβασης σύνδεσης",
    "IRC channel" : "Κανάλι IRC",
    "Channel password" : "Κωδικός πρόσβασης καναλιού",
    "NickServ nickname" : "Ψευδώνυμο NickServ",
    "NickServ password" : "Κωδικός πρόσβασης NickServ",
    "Use TLS" : "Χρήση TLS",
    "Use SASL" : "Χρήση SASL",
    "Tenant ID" : "Ταυτότητα Tenant",
    "Client ID" : "ID πελάτη",
    "Team ID" : "Ταυτότητα ομάδας",
    "Thread ID" : "Thread ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber διακομιστής URL",
    "MUC server URL" : "Διεύθυνση URL διακομιστή MUC",
    "Jabber ID" : "Ταυτότητα Jabber",
    "Media" : "Μέσα ενημέρωσης",
    "Polls" : "Δημοσκοπήσεις",
    "Deck cards" : "Καρτέλες Deck",
    "Voice messages" : "Φωνητικά μηνύματα",
    "Locations" : "Τοποθεσίες",
    "Call recordings" : "Εγγραφές κλήσεων",
    "Audio" : "Ήχος",
    "Show all media" : "Εμφάνιση όλων των πολυμέσων",
    "Show all files" : "Εμφάνιση όλων των αρχείων",
    "Show all polls" : "Εμφάνιση όλων των δημοσκοπήσεων",
    "Show all deck cards" : "Εμφάνιση όλων των καρτελών Deck",
    "Show all voice messages" : "Εμφάνιση όλων των φωνητικών μηνυμάτων",
    "Show all locations" : "Εμφάνιση όλων των τοποθεσιών",
    "Show all call recordings" : "Εμφάνιση όλων των εγγραφών κλήσεων",
    "Show all audio" : "Εμφάνιση όλων των ήχων",
    "Show all other" : "Εμφάνιση όλων των άλλων",
    "Follow conversation settings" : "Ακολούθηση ρυθμίσεων συνομιλίας",
    "Group" : "Ομάδα",
    "Team" : "Ομάδα",
    "You reconnected to the call" : "Επανασυνδεθήκατε στην κλήση",
    "{actor} reconnected to the call" : "Ο {actor} επανασυνδέθηκε στην κλήση",
    "You added {user0} and {user1}" : "Προσθέσατε τους {user0} και {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Προσθέσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Προσθέσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "An administrator added you and {user0}" : "Ένας διαχειριστής πρόσθεσε εσάς και τον {user0}",
    "{actor} added you and {user0}" : "Ο {actor} πρόσθεσε εσάς και τον {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Ένας διαχειριστής πρόσθεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντα","Ένας διαχειριστής πρόσθεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντες"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["Ο {actor} πρόσθεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντα","Ο {actor} πρόσθεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντες"],
    "An administrator added {user0} and {user1}" : "Ένας διαχειριστής πρόσθεσε τους {user0} και {user1}",
    "{actor} added {user0} and {user1}" : "Ο {actor} πρόσθεσε τους {user0} και {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Ένας διαχειριστής πρόσθεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Ένας διαχειριστής πρόσθεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["Ο {actor} πρόσθεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Ο {actor} πρόσθεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "You removed {user0} and {user1}" : "Αφαιρέσατε τους {user0} και {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Αφαιρέσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Αφαιρέσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "An administrator removed you and {user0}" : "Ένας διαχειριστής αφαίρεσε εσάς και τον {user0}",
    "{actor} removed you and {user0}" : "Ο {actor} αφαίρεσε εσάς και τον {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Ένας διαχειριστής αφαίρεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντα","Ένας διαχειριστής αφαίρεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντες"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["Ο {actor} αφαίρεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντα","Ο {actor} αφαίρεσε εσάς, τον {user0} και %n ακόμα συμμετέχοντες"],
    "An administrator removed {user0} and {user1}" : "Ένας διαχειριστής αφαίρεσε τους {user0} και {user1}",
    "{actor} removed {user0} and {user1}" : "Ο {actor} αφαίρεσε τους {user0} και {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Ένας διαχειριστής αφαίρεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Ένας διαχειριστής αφαίρεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["Ο {actor} αφαίρεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντα","Ο {actor} αφαίρεσε τους {user0}, {user1} και %n ακόμα συμμετέχοντες"],
    "You and {user0} joined the call" : "Εσείς και ο {user0} συμμετείχατε στην κλήση",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Εσείς, ο {user0} και %n ακόμα συμμετέχοντας συμμετείχατε στην κλήση","Εσείς, ο {user0} και %n ακόμα συμμετέχοντες συμμετείχατε στην κλήση"],
    "{user0} and {user1} joined the call" : "Οι {user0} και {user1} συμμετείχατε στην κλήση",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["Οι {user0}, {user1} και %n ακόμα συμμετέχοντας συμμετείχατε στην κλήση","Οι {user0}, {user1} και %n ακόμα συμμετέχοντες συμμετείχατε στην κλήση"],
    "You and {user0} left the call" : "Εσείς και ο {user0} αποχωρήσατε από την κλήση",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Εσείς, ο {user0} και %n ακόμα συμμετέχοντας αποχωρήσατε από την κλήση","Εσείς, ο {user0} και %n ακόμα συμμετέχοντες αποχωρήσατε από την κλήση"],
    "{user0} and {user1} left the call" : "Οι {user0} και {user1} αποχωρήσατε από την κλήση",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["Οι {user0}, {user1} και %n ακόμα συμμετέχοντας αποχωρήσατε από την κλήση","Οι {user0}, {user1} και %n ακόμα συμμετέχοντες αποχωρήσατε από την κλήση"],
    "You promoted {user0} and {user1} to moderators" : "Προήγατε τους {user0} και {user1} σε συντονιστές",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Προήγατε τους {user0}, {user1} και %n ακόμα συμμετέχοντα σε συντονιστές","Προήγατε τους {user0}, {user1} και %n ακόμα συμμετέχοντες σε συντονιστές"],
    "An administrator promoted you and {user0} to moderators" : "Ένας διαχειριστής σας προήγαγε εσάς και τον {user0} σε συντονιστές",
    "{actor} promoted you and {user0} to moderators" : "Ο {actor} σας προήγαγε εσάς και τον {user0} σε συντονιστές",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Ένας διαχειριστής σας προήγαγε εσάς, τον {user0} και %n ακόμα συμμετέχοντα σε συντονιστές","Ένας διαχειριστής σας προήγαγε εσάς, τον {user0} και %n ακόμα συμμετέχοντες σε συντονιστές"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["Ο {actor} σας προήγαγε εσάς, τον {user0} και %n ακόμα συμμετέχοντα σε συντονιστές","Ο {actor} σας προήγαγε εσάς, τον {user0} και %n ακόμα συμμετέχοντες σε συντονιστές"],
    "An administrator promoted {user0} and {user1} to moderators" : "Ένας διαχειριστής προήγαγε τους {user0} και {user1} σε συντονιστές",
    "{actor} promoted {user0} and {user1} to moderators" : "Ο {actor} προήγαγε τους {user0} και {user1} σε συντονιστές",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Ένας διαχειριστής προήγαγε τους {user0}, {user1} και %n ακόμα συμμετέχοντα σε συντονιστές","Ένας διαχειριστής προήγαγε τους {user0}, {user1} και %n ακόμα συμμετέχοντες σε συντονιστές"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["Ο {actor} προήγαγε τους {user0}, {user1} και %n ακόμα συμμετέχοντα σε συντονιστές","Ο {actor} προήγαγε τους {user0}, {user1} και %n ακόμα συμμετέχοντες σε συντονιστές"],
    "You demoted {user0} and {user1} from moderators" : "Υποβιβάσατε τους {user0} και {user1} από συντονιστές",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Υποβιβάσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντα από συντονιστές","Υποβιβάσατε τους {user0}, {user1} και %n ακόμα συμμετέχοντες από συντονιστές"],
    "An administrator demoted you and {user0} from moderators" : "Ένας διαχειριστής σας υποβίβασε εσάς και τον {user0} από συντονιστές",
    "{actor} demoted you and {user0} from moderators" : "Ο {actor} σας υποβίβασε εσάς και τον {user0} από συντονιστές",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Ένας διαχειριστής σας υποβίβασε εσάς, τον {user0} και %n ακόμα συμμετέχοντα από συντονιστές","Ένας διαχειριστής σας υποβίβασε εσάς, τον {user0} και %n ακόμα συμμετέχοντες από συντονιστές"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["Ο {actor} σας υποβίβασε εσάς, τον {user0} και %n ακόμα συμμετέχοντα από συντονιστές","Ο {actor} σας υποβίβασε εσάς, τον {user0} και %n ακόμα συμμετέχοντες από συντονιστές"],
    "An administrator demoted {user0} and {user1} from moderators" : "Ένας διαχειριστής υποβίβασε τους {user0} και {user1} από συντονιστές",
    "{actor} demoted {user0} and {user1} from moderators" : "Ο {actor} υποβίβασε τους {user0} και {user1} από συντονιστές",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Ένας διαχειριστής υποβίβασε τους {user0}, {user1} και %n ακόμα συμμετέχοντα από συντονιστές","Ένας διαχειριστής υποβίβασε τους {user0}, {user1} και %n ακόμα συμμετέχοντες από συντονιστές"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["Ο {actor} υποβίβασε τους {user0}, {user1} και %n ακόμα συμμετέχοντα από συντονιστές","Ο {actor} υποβίβασε τους {user0}, {user1} και %n ακόμα συμμετέχοντες από συντονιστές"],
    "You:" : "Εσείς:",
    "You: {lastMessage}" : "Εσείς: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(επεξεργασμένο από εσάς)",
    "(edited by a deleted user)" : "(επεξεργασμένο από διαγεγραμμένο χρήστη)",
    "(edited by {moderator})" : "(επεξεργασμένο από {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
    "Leave this page" : "Αποχώρηση από την σελίδα",
    "Join here" : "Συμμετέχετε εδώ",
    "Deck card has been posted to {conversation}" : "Η κάρτα Deck δημοσιεύτηκε στο {conversation}",
    "An error occurred while posting deck card to conversation" : "Παρουσιάστηκε σφάλμα κατά τη δημοσίευση της κάρτας Deck στη συνομιλία",
    "Post to a conversation" : "Δημοσίευση σε συνομιλία",
    "Post to conversation" : "Δημοσίευση σε συνομιλία",
    "The recording failed. Please contact your administrator." : "Η εγγραφή απέτυχε. Παρακαλούμε επικοινωνήστε με τον διαχειριστή σας.",
    "Location has been posted to {conversation}" : "Η τοποθεσία δημοσιεύτηκε στο {conversation}",
    "An error occurred while posting location to conversation" : "Παρουσιάστηκε σφάλμα κατά τη δημοσίευση της τοποθεσίας στη συνομιλία",
    "Share to a conversation" : "Κοινή χρήση σε συνομιλία",
    "Share to conversation" : "Κοινή χρήση σε συνομιλία",
    "In conversation" : "Σε συνομιλία",
    "Search in conversation: {conversation}" : "Αναζήτηση στη συνομιλία: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Τα αιτήματά σας περιορίζονται προς το παρόν λόγω προστασίας από brute force",
    "Error while clearing conversation history" : "Σφάλμα κατά την εκκαθάριση του ιστορικού συνομιλιών",
    "Error occurred while allowing guests" : "Παρουσιάστηκε σφάλμα κατά την άδεια των επισκεπτών",
    "Error occurred while disallowing guests" : "Παρουσιάστηκε σφάλμα κατά την απαγόρευση των επισκεπτών",
    "Error occurred when restricting the conversation to moderator" : "Παρουσιάστηκε σφάλμα κατά τον περιορισμό της συνομιλίας σε επόπτη",
    "Error occurred when opening the conversation to everyone" : "Παρουσιάστηκε σφάλμα κατά το άνοιγμα της συνομιλίας σε όλους",
    "Conversation password has been saved" : "Ο κωδικός πρόσβασης συνομιλίας έχει αποθηκευτεί",
    "Conversation password has been removed" : "Ο κωδικός πρόσβασης συνομιλίας έχει αφαιρεθεί",
    "Error occurred while saving conversation password" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του κωδικού πρόσβασης συνομιλίας",
    "Call recording is starting." : "Η εγγραφή κλήσης ξεκινά.",
    "Call recording stopped while starting." : "Η εγγραφή κλήσης σταμάτησε κατά την εκκίνηση.",
    "Call recording stopped. You will be notified once the recording is available." : "Η εγγραφή κλήσης σταμάτησε. Θα ειδοποιηθείτε μόλις η εγγραφή είναι διαθέσιμη.",
    "Conversation picture set" : "Ορίστηκε εικόνα συνομιλίας",
    "Conversation picture deleted" : "Διαγράφηκε η εικόνα συνομιλίας",
    "Could not delete the conversation picture" : "Δεν ήταν δυνατή η διαγραφή της εικόνας συνομιλίας",
    "Could not remove the automatic expiration" : "Δεν ήταν δυνατή η αφαίρεση της αυτόματης λήξης",
    "Could not post message: {errorMessage}" : "Δεν ήταν δυνατή η δημοσίευση μηνύματος: {errorMessage}",
    "Participant is banned successfully" : "Ο συμμετέχων αποκλείστηκε με επιτυχία",
    "Error while banning the participant" : "Σφάλμα κατά τον αποκλεισμό του συμμετέχοντα",
    "An error occurred while fetching the participants" : "Παρουσιάστηκε σφάλμα κατά την ανάκτηση των συμμετεχόντων",
    "Could not send invitation to {actorId}" : "Δεν ήταν δυνατή η αποστολή πρόσκλησης στον {actorId}",
    "Invitations sent" : "Η προσκλήσεις στάλθηκαν",
    "Error occurred when sending invitations" : "Παρουσιάστηκε σφάλμα κατά την αποστολή προσκλήσεων",
    "Failed to join the conversation." : "Αποτυχία συμμετοχής στη συνομιλία.",
    "An error occurred while creating breakout rooms" : "Παρουσιάστηκε σφάλμα κατά τη δημιουργία δωματίων διάσπασης",
    "An error occurred while re-ordering the attendees" : "Παρουσιάστηκε σφάλμα κατά την αναδιάταξη των συμμετεχόντων",
    "An error occurred while deleting breakout rooms" : "Παρουσιάστηκε σφάλμα κατά τη διαγραφή δωματίων διάσπασης",
    "An error occurred while starting breakout rooms" : "Παρουσιάστηκε σφάλμα κατά την έναρξη δωματίων διάσπασης",
    "An error occurred while stopping breakout rooms" : "Παρουσιάστηκε σφάλμα κατά τη διακοπή δωματίων διάσπασης",
    "An error occurred while sending a message to the breakout rooms" : "Παρουσιάστηκε σφάλμα κατά την αποστολή μηνύματος στα δωμάτια διάσπασης",
    "An error occurred while requesting assistance" : "Παρουσιάστηκε σφάλμα κατά την αίτηση βοήθειας",
    "An error occurred while resetting the request for assistance" : "Παρουσιάστηκε σφάλμα κατά την επαναφορά της αίτησης βοήθειας",
    "An error occurred while joining breakout room" : "Παρουσιάστηκε σφάλμα κατά τη συμμετοχή σε δωμάτιο διάσπασης",
    "Failed to rename the thread" : "Αποτυχία μετονομασίας της συζήτησης",
    "Error fetching upcoming events" : "Σφάλμα ανάκτησης επερχόμενων συμβάντων",
    "Error fetching upcoming reminders" : "Σφάλμα ανάκτησης επερχόμενων υπενθυμίσεων",
    "An error occurred while accepting an invitation" : "Παρουσιάστηκε σφάλμα κατά την αποδοχή πρόσκλησης",
    "An error occurred while rejecting an invitation" : "Παρουσιάστηκε σφάλμα κατά την απόρριψη πρόσκλησης",
    "{guest} (guest)" : "{guest} (επισκέπτης)",
    "Poll draft has been saved" : "Το προσχέδιο δημοσκόπησης αποθηκεύτηκε",
    "An error occurred while saving the draft" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του προσχεδίου",
    "An error occurred while submitting your vote" : "Παρουσιάστηκε σφάλμα κατά την υποβολή της ψήφου σας",
    "An error occurred while ending the poll" : "Παρουσιάστηκε σφάλμα κατά τον τερματισμό της δημοσκόπησης",
    "An error occurred while deleting the poll draft" : "Παρουσιάστηκε σφάλμα κατά τη διαγραφή του προσχεδίου δημοσκόπησης",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Η δημοσκόπηση \"{name}\" δημιουργήθηκε από τον {user}. Κάντε κλικ για να ψηφίσετε",
    "Failed to add reaction" : "Αποτυχία προσθήκης αντίδρασης",
    "Failed to remove reaction" : "Αποτυχία αφαίρεσης αντίδρασης",
    "Error while uploading file \"{fileName}\"" : "Σφάλμα κατά την μεταφόρτωση του αρχείου \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Δεν επαρκεί ο ελεύθερος χώρος για τη μεταφόρτωση του αρχείου \"{fileName}\"",
    "You are not allowed to share files" : "Δεν επιτρέπεται να μοιράζεστε αρχεία",
    "Error while sharing file" : "Σφάλμα κατά τον διαμοιρασμό αρχείου",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Ο περιηγητής που χρησιμοποιείτε δεν υποστηρίζεται πλήρως από το Nextcloud Talk. Παρακαλώ χρησιμοποιήστε την τελευταία έκδοση του Mozilla Firefox, Microsoft Edge, Google Chrome ή Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Σε %n ώρα","Σε %n ώρες"],
    "_%n minute _::_%n minutes_" : ["%n λεπτό","%n λεπτά"],
    "In {hours} and {minutes}" : "Σε {hours} και {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Σε %n λεπτό","Σε %n λεπτά"],
    "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
    "This weekend – {timeLocale}" : "Αυτό το σαββατοκύριακο – {timeLocale}",
    "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
    "Conversation link copied to clipboard" : "Ο σύνδεσμος συνομιλίας αντιγράφηκε στο πρόχειρο",
    "The link could not be copied" : "Ο σύνδεσμος δεν μπορούσε να αντιγραφεί",
    "Error while parsing a PROPFIND error" : "Σφάλμα κατά την ανάλυση σφάλματος PROPFIND",
    "Sending signaling message has failed" : "Η αποστολή μηνύματος σηματοδότησης απέτυχε",
    "Lost connection to signaling server. Trying to reconnect." : "Χάθηκε η σύνδεση με τον διακομιστή σηματοδοσίας. Προσπάθεια επανασύνδεσης.",
    "Lost connection to signaling server." : "Έχασε η σύνδεση με τον διακομιστή σηματοδότησης.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Ο διαμορφωμένος διακομιστής σηματοδότησης πρέπει να ενημερωθεί για να είναι συμβατός με αυτήν την έκδοση του Talk. Παρακαλούμε επικοινωνήστε με τη διοίκησή σας.",
    "Please restart the app." : "Παρακαλούμε επανεκκινήστε την εφαρμογή.",
    "Please reload the page." : "Παρακαλούμε φορτώστε ξανά τη σελίδα.",
    "Please try to restart the app." : "Παρακαλούμε προσπαθήστε να επανεκκινήσετε την εφαρμογή.",
    "Please try to reload the page." : "Παρακαλούμε προσπαθήστε να φορτώσετε ξανά τη σελίδα.",
    "Do not disturb" : "Μην ενοχλείτε",
    "Away" : "Λείπω",
    "Microphone {number}" : "Μικρόφωνο {number}",
    "Camera {number}" : "Κάμερα {number}",
    "Speaker {number}" : "Speaker {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Φαίνεται ότι μιλάτε ενώ είστε σε σίγαση, παρακαλώ ενεργοποιήστε τον ήχο σας για να ακουστείτε",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Δεν μπορεί να αποκατασταθεί η σύνδεση με τουλάχιστον ένα συμμετέχοντα. Ένας διακομιστής TURN ίσως απαιτείται για την περίπτωσή σας. Παρακαλώ ρωτήστε τον διαχειριστή σας για εγκατάσταση από τα ακόλουθα  {linkstart}τεκμηρίωση{linkstart}",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Διαρκεί περισσότερο από το αναμενόμενο. Τα δικαιώματα των μέσων επικοινωνίας έχουν χορηγηθεί (ή απορριφθεί); Εάν ναι, κάντε επανεκκίνηση του προγράμματος περιήγησής σας, λόγω αποτυχιας του ήχου και του βίντεο",
    "Access to microphone & camera is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο και στην κάμερα είναι εφικτή μόνο μέσω HTTPS",
    "Please move your setup to HTTPS" : "Παρακαλώ μεταφέρεται την εγκατάσταση σας σε HTTPS",
    "Access to microphone & camera was denied" : "Άρνηση πρόσβασης στο μικρόφωνο & την κάμερα",
    "WebRTC is not supported in your browser" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας",
    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
    "Error while accessing microphone & camera" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο & την κάμερα",
    "%s Talk on your mobile devices" : "%s Talk στις κινητές συσκευές σας",
    "Join conversations at any time, anywhere, on any device." : "Συμμετέχετε σε συνομιλίες πάντα και παντού από όλες τις συσκευές.",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "__language_name__" : "Ελληνικά",
    "Webhook Demo" : "Επίδειξη Webhook",
    "Call summary (%s)" : "Περίληψη κλήσης (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Το bot περίληψης κλήσης δημοσιεύει ένα μήνυμα επισκόπησης μετά την κλήση που παραθέτει όλους τους συμμετέχοντες και σκιαγραφεί εργασίες",
    "Tasks" : "Εργασίες",
    "Notes" : "Σημειώσεις",
    "Reports" : "Αναφορές",
    "Decisions" : "Αποφάσεις",
    "Agenda" : "Ημερήσια διάταξη",
    "Call summary" : "Περίληψη κλήσης",
    "Call summary - {title}" : "Περίληψη κλήσης - {title}",
    "Talk conversation for event" : "Συνομιλία Talk για συμβάν",
    "Client Push is installed, this improves the performance of desktop clients." : "Το Client Push είναι εγκατεστημένο, αυτό βελτιώνει την απόδοση των πελατών επιφάνειας εργασίας.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "Το {notify_push} δεν είναι εγκατεστημένο, αυτό μπορεί να οδηγήσει σε προβλήματα απόδοσης όταν χρησιμοποιούνται πελάτες επιφάνειας εργασίας.",
    "Next meeting" : "Επόμενη συνάντηση",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Προγραμματίστε μια συνάντηση από το ημερολόγιό σας. Μια συνομιλία Talk πρέπει να οριστεί ως τοποθεσία για να εμφανίζεται εδώ",
    "Join conversations from remote Nextcloud servers" : "Συμμετοχή σε συνομιλίες από απομακρυσμένους διακομιστές Nextcloud",
    "Your default media state has been saved" : "Η προεπιλεγμένη κατάσταση πολυμέσων σας αποθηκεύτηκε",
    "Set reminder for later today" : "Ορισμός υπενθύμισης για αργότερα σήμερα",
    "Set reminder for tomorrow" : "Ορισμός υπενθύμισης για αύριο",
    "Set reminder for this weekend" : "Ορισμός υπενθύμισης για αυτό το σαββατοκύριακο",
    "Set reminder for next week" : "Ορισμός υπενθύμισης για την επόμενη εβδομάδα",
    "Generate summary" : "Δημιουργία σύνοψης",
    "Open poll • You voted already" : "Άνοιγμα δημοσκόπησης • Έχετε ήδη ψηφίσει",
    "Open poll • Click to vote" : "Άνοιγμα δημοσκόπησης • Κάντε κλικ για να ψηφίσετε",
    "Poll • Ended" : "Δημοσκόπηση • Ολοκληρώθηκε",
    "Talk recording from {time} ({conversation})" : "Εγγραφή ομιλίας από {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Αποτελέσματα δημοσκόπησης • %n ψήφος","Αποτελέσματα δημοσκόπησης • %n ψήφοι"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Ανοιχτή δημοσκόπηση • %n ψήφος","Ανοιχτή δημοσκόπηση • %n ψήφοι"],
    "Submit vote" : "Υποβολή ψήφου",
    "Your privacy setting has been saved" : "Η ρύθμιση απορρήτου σας έχει αποθηκευτεί",
    "Your personal setting has been saved" : "Η προσωπική σας ρύθμιση έχει αποθηκευτεί",
    "Failed to save sounds setting" : "Αποτυχία αποθήκευσης της ρύθμισης ήχων",
    "Sounds setting saved" : "Η ρύθμιση ήχων αποθηκεύτηκε",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Το Nextcloud Talk ενημερώθηκε, δεν μπορείτε να ξεκινήσετε ή να συμμετάσχετε σε κλήση.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Συμμετείχατε στη συνομιλία σε άλλο παράθυρο ή συσκευή. Αυτήν τη στιγμή δεν υποστηρίζεται από το Nextcloud Talk, επομένως αυτή η συνεδρία τερματίστηκε.",
    "Nextcloud Talk was updated." : "Το Nextcloud Talk ενημερώθηκε.",
    "Nextcloud is in maintenance mode." : "Το Nextcloud βρίσκεται σε λειτουργία συντήρησης.",
    "Nextcloud Talk Federation was updated." : "Το Nextcloud Talk Federation ενημερώθηκε."
},
"nplurals=2; plural=(n != 1);");
